mocks

package
v1.16.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 2, 2025 License: Apache-2.0 Imports: 5 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type CheckpointPaths

type CheckpointPaths struct {
	mock.Mock
}

CheckpointPaths is an autogenerated mock type for the CheckpointPaths type

func NewCheckpointPaths added in v1.15.1

func NewCheckpointPaths(t interface {
	mock.TestingT
	Cleanup(func())
}) *CheckpointPaths

NewCheckpointPaths creates a new instance of CheckpointPaths. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*CheckpointPaths) EXPECT added in v1.15.1

func (*CheckpointPaths) GetCheckpointPrefix

func (_m *CheckpointPaths) GetCheckpointPrefix() storage.DataReference

GetCheckpointPrefix provides a mock function with no fields

func (*CheckpointPaths) GetPreviousCheckpointsPrefix

func (_m *CheckpointPaths) GetPreviousCheckpointsPrefix() storage.DataReference

GetPreviousCheckpointsPrefix provides a mock function with no fields

type CheckpointPaths_Expecter added in v1.15.1

type CheckpointPaths_Expecter struct {
	// contains filtered or unexported fields
}

func (*CheckpointPaths_Expecter) GetCheckpointPrefix added in v1.15.1

GetCheckpointPrefix is a helper method to define mock.On call

func (*CheckpointPaths_Expecter) GetPreviousCheckpointsPrefix added in v1.15.1

GetPreviousCheckpointsPrefix is a helper method to define mock.On call

type CheckpointPaths_GetCheckpointPrefix_Call added in v1.15.1

type CheckpointPaths_GetCheckpointPrefix_Call struct {
	*mock.Call
}

CheckpointPaths_GetCheckpointPrefix_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetCheckpointPrefix'

func (*CheckpointPaths_GetCheckpointPrefix_Call) Return added in v1.15.1

func (*CheckpointPaths_GetCheckpointPrefix_Call) Run added in v1.15.1

func (*CheckpointPaths_GetCheckpointPrefix_Call) RunAndReturn added in v1.15.1

type CheckpointPaths_GetPreviousCheckpointsPrefix_Call added in v1.15.1

type CheckpointPaths_GetPreviousCheckpointsPrefix_Call struct {
	*mock.Call
}

CheckpointPaths_GetPreviousCheckpointsPrefix_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetPreviousCheckpointsPrefix'

func (*CheckpointPaths_GetPreviousCheckpointsPrefix_Call) Return added in v1.15.1

func (*CheckpointPaths_GetPreviousCheckpointsPrefix_Call) Run added in v1.15.1

func (*CheckpointPaths_GetPreviousCheckpointsPrefix_Call) RunAndReturn added in v1.15.1

type ErrorReader added in v1.14.0

type ErrorReader struct {
	mock.Mock
}

ErrorReader is an autogenerated mock type for the ErrorReader type

func NewErrorReader added in v1.15.1

func NewErrorReader(t interface {
	mock.TestingT
	Cleanup(func())
}) *ErrorReader

NewErrorReader creates a new instance of ErrorReader. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*ErrorReader) EXPECT added in v1.15.1

func (_m *ErrorReader) EXPECT() *ErrorReader_Expecter

func (*ErrorReader) IsError added in v1.14.0

func (_m *ErrorReader) IsError(ctx context.Context) (bool, error)

IsError provides a mock function with given fields: ctx

func (*ErrorReader) ReadError added in v1.14.0

func (_m *ErrorReader) ReadError(ctx context.Context) (io.ExecutionError, error)

ReadError provides a mock function with given fields: ctx

type ErrorReader_Expecter added in v1.15.1

type ErrorReader_Expecter struct {
	// contains filtered or unexported fields
}

func (*ErrorReader_Expecter) IsError added in v1.15.1

func (_e *ErrorReader_Expecter) IsError(ctx interface{}) *ErrorReader_IsError_Call

IsError is a helper method to define mock.On call

  • ctx context.Context

func (*ErrorReader_Expecter) ReadError added in v1.15.1

func (_e *ErrorReader_Expecter) ReadError(ctx interface{}) *ErrorReader_ReadError_Call

ReadError is a helper method to define mock.On call

  • ctx context.Context

type ErrorReader_IsError_Call added in v1.15.1

type ErrorReader_IsError_Call struct {
	*mock.Call
}

ErrorReader_IsError_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'IsError'

func (*ErrorReader_IsError_Call) Return added in v1.15.1

func (*ErrorReader_IsError_Call) Run added in v1.15.1

func (*ErrorReader_IsError_Call) RunAndReturn added in v1.15.1

type ErrorReader_ReadError_Call added in v1.15.1

type ErrorReader_ReadError_Call struct {
	*mock.Call
}

ErrorReader_ReadError_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'ReadError'

func (*ErrorReader_ReadError_Call) Return added in v1.15.1

func (*ErrorReader_ReadError_Call) Run added in v1.15.1

func (*ErrorReader_ReadError_Call) RunAndReturn added in v1.15.1

type InputFilePaths

type InputFilePaths struct {
	mock.Mock
}

InputFilePaths is an autogenerated mock type for the InputFilePaths type

func NewInputFilePaths added in v1.15.1

func NewInputFilePaths(t interface {
	mock.TestingT
	Cleanup(func())
}) *InputFilePaths

NewInputFilePaths creates a new instance of InputFilePaths. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*InputFilePaths) EXPECT added in v1.15.1

func (*InputFilePaths) GetInputPath

func (_m *InputFilePaths) GetInputPath() storage.DataReference

GetInputPath provides a mock function with no fields

func (*InputFilePaths) GetInputPrefixPath

func (_m *InputFilePaths) GetInputPrefixPath() storage.DataReference

GetInputPrefixPath provides a mock function with no fields

type InputFilePaths_Expecter added in v1.15.1

type InputFilePaths_Expecter struct {
	// contains filtered or unexported fields
}

func (*InputFilePaths_Expecter) GetInputPath added in v1.15.1

GetInputPath is a helper method to define mock.On call

func (*InputFilePaths_Expecter) GetInputPrefixPath added in v1.15.1

GetInputPrefixPath is a helper method to define mock.On call

type InputFilePaths_GetInputPath_Call added in v1.15.1

type InputFilePaths_GetInputPath_Call struct {
	*mock.Call
}

InputFilePaths_GetInputPath_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetInputPath'

func (*InputFilePaths_GetInputPath_Call) Return added in v1.15.1

func (*InputFilePaths_GetInputPath_Call) Run added in v1.15.1

func (*InputFilePaths_GetInputPath_Call) RunAndReturn added in v1.15.1

type InputFilePaths_GetInputPrefixPath_Call added in v1.15.1

type InputFilePaths_GetInputPrefixPath_Call struct {
	*mock.Call
}

InputFilePaths_GetInputPrefixPath_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetInputPrefixPath'

func (*InputFilePaths_GetInputPrefixPath_Call) Return added in v1.15.1

func (*InputFilePaths_GetInputPrefixPath_Call) Run added in v1.15.1

func (*InputFilePaths_GetInputPrefixPath_Call) RunAndReturn added in v1.15.1

type InputReader

type InputReader struct {
	mock.Mock
}

InputReader is an autogenerated mock type for the InputReader type

func NewInputReader added in v1.15.1

func NewInputReader(t interface {
	mock.TestingT
	Cleanup(func())
}) *InputReader

NewInputReader creates a new instance of InputReader. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*InputReader) EXPECT added in v1.15.1

func (_m *InputReader) EXPECT() *InputReader_Expecter

func (*InputReader) Get

func (_m *InputReader) Get(ctx context.Context) (*core.LiteralMap, error)

Get provides a mock function with given fields: ctx

func (*InputReader) GetInputPath

func (_m *InputReader) GetInputPath() storage.DataReference

GetInputPath provides a mock function with no fields

func (*InputReader) GetInputPrefixPath

func (_m *InputReader) GetInputPrefixPath() storage.DataReference

GetInputPrefixPath provides a mock function with no fields

type InputReader_Expecter added in v1.15.1

type InputReader_Expecter struct {
	// contains filtered or unexported fields
}

func (*InputReader_Expecter) Get added in v1.15.1

func (_e *InputReader_Expecter) Get(ctx interface{}) *InputReader_Get_Call

Get is a helper method to define mock.On call

  • ctx context.Context

func (*InputReader_Expecter) GetInputPath added in v1.15.1

GetInputPath is a helper method to define mock.On call

func (*InputReader_Expecter) GetInputPrefixPath added in v1.15.1

GetInputPrefixPath is a helper method to define mock.On call

type InputReader_GetInputPath_Call added in v1.15.1

type InputReader_GetInputPath_Call struct {
	*mock.Call
}

InputReader_GetInputPath_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetInputPath'

func (*InputReader_GetInputPath_Call) Return added in v1.15.1

func (*InputReader_GetInputPath_Call) Run added in v1.15.1

func (*InputReader_GetInputPath_Call) RunAndReturn added in v1.15.1

type InputReader_GetInputPrefixPath_Call added in v1.15.1

type InputReader_GetInputPrefixPath_Call struct {
	*mock.Call
}

InputReader_GetInputPrefixPath_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetInputPrefixPath'

func (*InputReader_GetInputPrefixPath_Call) Return added in v1.15.1

func (*InputReader_GetInputPrefixPath_Call) Run added in v1.15.1

func (*InputReader_GetInputPrefixPath_Call) RunAndReturn added in v1.15.1

type InputReader_Get_Call added in v1.15.1

type InputReader_Get_Call struct {
	*mock.Call
}

InputReader_Get_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Get'

func (*InputReader_Get_Call) Return added in v1.15.1

func (*InputReader_Get_Call) Run added in v1.15.1

func (_c *InputReader_Get_Call) Run(run func(ctx context.Context)) *InputReader_Get_Call

func (*InputReader_Get_Call) RunAndReturn added in v1.15.1

type OutputDataSandbox

type OutputDataSandbox struct {
	mock.Mock
}

RawOutputPaths is an autogenerated mock type for the RawOutputPaths type

func (*OutputDataSandbox) GetRawOutputPrefix

func (_m *OutputDataSandbox) GetRawOutputPrefix() storage.DataReference

GetRawOutputPrefix provides a mock function with given fields:

func (*OutputDataSandbox) OnGetOutputDataSandboxPath

func (_m *OutputDataSandbox) OnGetOutputDataSandboxPath() *OutputDataSandbox_GetOutputDataSandboxPath

func (*OutputDataSandbox) OnGetOutputDataSandboxPathMatch

func (_m *OutputDataSandbox) OnGetOutputDataSandboxPathMatch(matchers ...interface{}) *OutputDataSandbox_GetOutputDataSandboxPath

type OutputDataSandbox_GetOutputDataSandboxPath

type OutputDataSandbox_GetOutputDataSandboxPath struct {
	*mock.Call
}

func (OutputDataSandbox_GetOutputDataSandboxPath) Return

type OutputFilePaths

type OutputFilePaths struct {
	mock.Mock
}

OutputFilePaths is an autogenerated mock type for the OutputFilePaths type

func NewOutputFilePaths added in v1.15.1

func NewOutputFilePaths(t interface {
	mock.TestingT
	Cleanup(func())
}) *OutputFilePaths

NewOutputFilePaths creates a new instance of OutputFilePaths. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*OutputFilePaths) EXPECT added in v1.15.1

func (*OutputFilePaths) GetCheckpointPrefix

func (_m *OutputFilePaths) GetCheckpointPrefix() storage.DataReference

GetCheckpointPrefix provides a mock function with no fields

func (*OutputFilePaths) GetDeckPath

func (_m *OutputFilePaths) GetDeckPath() storage.DataReference

GetDeckPath provides a mock function with no fields

func (*OutputFilePaths) GetErrorPath

func (_m *OutputFilePaths) GetErrorPath() storage.DataReference

GetErrorPath provides a mock function with no fields

func (*OutputFilePaths) GetOutputPath

func (_m *OutputFilePaths) GetOutputPath() storage.DataReference

GetOutputPath provides a mock function with no fields

func (*OutputFilePaths) GetOutputPrefixPath

func (_m *OutputFilePaths) GetOutputPrefixPath() storage.DataReference

GetOutputPrefixPath provides a mock function with no fields

func (*OutputFilePaths) GetPreviousCheckpointsPrefix

func (_m *OutputFilePaths) GetPreviousCheckpointsPrefix() storage.DataReference

GetPreviousCheckpointsPrefix provides a mock function with no fields

func (*OutputFilePaths) GetRawOutputPrefix

func (_m *OutputFilePaths) GetRawOutputPrefix() storage.DataReference

GetRawOutputPrefix provides a mock function with no fields

type OutputFilePaths_Expecter added in v1.15.1

type OutputFilePaths_Expecter struct {
	// contains filtered or unexported fields
}

func (*OutputFilePaths_Expecter) GetCheckpointPrefix added in v1.15.1

GetCheckpointPrefix is a helper method to define mock.On call

func (*OutputFilePaths_Expecter) GetDeckPath added in v1.15.1

GetDeckPath is a helper method to define mock.On call

func (*OutputFilePaths_Expecter) GetErrorPath added in v1.15.1

GetErrorPath is a helper method to define mock.On call

func (*OutputFilePaths_Expecter) GetOutputPath added in v1.15.1

GetOutputPath is a helper method to define mock.On call

func (*OutputFilePaths_Expecter) GetOutputPrefixPath added in v1.15.1

GetOutputPrefixPath is a helper method to define mock.On call

func (*OutputFilePaths_Expecter) GetPreviousCheckpointsPrefix added in v1.15.1

GetPreviousCheckpointsPrefix is a helper method to define mock.On call

func (*OutputFilePaths_Expecter) GetRawOutputPrefix added in v1.15.1

GetRawOutputPrefix is a helper method to define mock.On call

type OutputFilePaths_GetCheckpointPrefix_Call added in v1.15.1

type OutputFilePaths_GetCheckpointPrefix_Call struct {
	*mock.Call
}

OutputFilePaths_GetCheckpointPrefix_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetCheckpointPrefix'

func (*OutputFilePaths_GetCheckpointPrefix_Call) Return added in v1.15.1

func (*OutputFilePaths_GetCheckpointPrefix_Call) Run added in v1.15.1

func (*OutputFilePaths_GetCheckpointPrefix_Call) RunAndReturn added in v1.15.1

type OutputFilePaths_GetDeckPath_Call added in v1.15.1

type OutputFilePaths_GetDeckPath_Call struct {
	*mock.Call
}

OutputFilePaths_GetDeckPath_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetDeckPath'

func (*OutputFilePaths_GetDeckPath_Call) Return added in v1.15.1

func (*OutputFilePaths_GetDeckPath_Call) Run added in v1.15.1

func (*OutputFilePaths_GetDeckPath_Call) RunAndReturn added in v1.15.1

type OutputFilePaths_GetErrorPath_Call added in v1.15.1

type OutputFilePaths_GetErrorPath_Call struct {
	*mock.Call
}

OutputFilePaths_GetErrorPath_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetErrorPath'

func (*OutputFilePaths_GetErrorPath_Call) Return added in v1.15.1

func (*OutputFilePaths_GetErrorPath_Call) Run added in v1.15.1

func (*OutputFilePaths_GetErrorPath_Call) RunAndReturn added in v1.15.1

type OutputFilePaths_GetOutputPath_Call added in v1.15.1

type OutputFilePaths_GetOutputPath_Call struct {
	*mock.Call
}

OutputFilePaths_GetOutputPath_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetOutputPath'

func (*OutputFilePaths_GetOutputPath_Call) Return added in v1.15.1

func (*OutputFilePaths_GetOutputPath_Call) Run added in v1.15.1

func (*OutputFilePaths_GetOutputPath_Call) RunAndReturn added in v1.15.1

type OutputFilePaths_GetOutputPrefixPath_Call added in v1.15.1

type OutputFilePaths_GetOutputPrefixPath_Call struct {
	*mock.Call
}

OutputFilePaths_GetOutputPrefixPath_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetOutputPrefixPath'

func (*OutputFilePaths_GetOutputPrefixPath_Call) Return added in v1.15.1

func (*OutputFilePaths_GetOutputPrefixPath_Call) Run added in v1.15.1

func (*OutputFilePaths_GetOutputPrefixPath_Call) RunAndReturn added in v1.15.1

type OutputFilePaths_GetPreviousCheckpointsPrefix_Call added in v1.15.1

type OutputFilePaths_GetPreviousCheckpointsPrefix_Call struct {
	*mock.Call
}

OutputFilePaths_GetPreviousCheckpointsPrefix_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetPreviousCheckpointsPrefix'

func (*OutputFilePaths_GetPreviousCheckpointsPrefix_Call) Return added in v1.15.1

func (*OutputFilePaths_GetPreviousCheckpointsPrefix_Call) Run added in v1.15.1

func (*OutputFilePaths_GetPreviousCheckpointsPrefix_Call) RunAndReturn added in v1.15.1

type OutputFilePaths_GetRawOutputPrefix_Call added in v1.15.1

type OutputFilePaths_GetRawOutputPrefix_Call struct {
	*mock.Call
}

OutputFilePaths_GetRawOutputPrefix_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetRawOutputPrefix'

func (*OutputFilePaths_GetRawOutputPrefix_Call) Return added in v1.15.1

func (*OutputFilePaths_GetRawOutputPrefix_Call) Run added in v1.15.1

func (*OutputFilePaths_GetRawOutputPrefix_Call) RunAndReturn added in v1.15.1

type OutputReader

type OutputReader struct {
	mock.Mock
}

OutputReader is an autogenerated mock type for the OutputReader type

func NewOutputReader added in v1.15.1

func NewOutputReader(t interface {
	mock.TestingT
	Cleanup(func())
}) *OutputReader

NewOutputReader creates a new instance of OutputReader. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*OutputReader) DeckExists

func (_m *OutputReader) DeckExists(ctx context.Context) (bool, error)

DeckExists provides a mock function with given fields: ctx

func (*OutputReader) EXPECT added in v1.15.1

func (_m *OutputReader) EXPECT() *OutputReader_Expecter

func (*OutputReader) Exists

func (_m *OutputReader) Exists(ctx context.Context) (bool, error)

Exists provides a mock function with given fields: ctx

func (*OutputReader) IsError

func (_m *OutputReader) IsError(ctx context.Context) (bool, error)

IsError provides a mock function with given fields: ctx

func (*OutputReader) IsFile

func (_m *OutputReader) IsFile(ctx context.Context) bool

IsFile provides a mock function with given fields: ctx

func (*OutputReader) Read

Read provides a mock function with given fields: ctx

func (*OutputReader) ReadError

func (_m *OutputReader) ReadError(ctx context.Context) (io.ExecutionError, error)

ReadError provides a mock function with given fields: ctx

type OutputReader_DeckExists_Call added in v1.15.1

type OutputReader_DeckExists_Call struct {
	*mock.Call
}

OutputReader_DeckExists_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'DeckExists'

func (*OutputReader_DeckExists_Call) Return added in v1.15.1

func (*OutputReader_DeckExists_Call) Run added in v1.15.1

func (*OutputReader_DeckExists_Call) RunAndReturn added in v1.15.1

type OutputReader_Exists_Call added in v1.15.1

type OutputReader_Exists_Call struct {
	*mock.Call
}

OutputReader_Exists_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Exists'

func (*OutputReader_Exists_Call) Return added in v1.15.1

func (*OutputReader_Exists_Call) Run added in v1.15.1

func (*OutputReader_Exists_Call) RunAndReturn added in v1.15.1

type OutputReader_Expecter added in v1.15.1

type OutputReader_Expecter struct {
	// contains filtered or unexported fields
}

func (*OutputReader_Expecter) DeckExists added in v1.15.1

func (_e *OutputReader_Expecter) DeckExists(ctx interface{}) *OutputReader_DeckExists_Call

DeckExists is a helper method to define mock.On call

  • ctx context.Context

func (*OutputReader_Expecter) Exists added in v1.15.1

func (_e *OutputReader_Expecter) Exists(ctx interface{}) *OutputReader_Exists_Call

Exists is a helper method to define mock.On call

  • ctx context.Context

func (*OutputReader_Expecter) IsError added in v1.15.1

func (_e *OutputReader_Expecter) IsError(ctx interface{}) *OutputReader_IsError_Call

IsError is a helper method to define mock.On call

  • ctx context.Context

func (*OutputReader_Expecter) IsFile added in v1.15.1

func (_e *OutputReader_Expecter) IsFile(ctx interface{}) *OutputReader_IsFile_Call

IsFile is a helper method to define mock.On call

  • ctx context.Context

func (*OutputReader_Expecter) Read added in v1.15.1

func (_e *OutputReader_Expecter) Read(ctx interface{}) *OutputReader_Read_Call

Read is a helper method to define mock.On call

  • ctx context.Context

func (*OutputReader_Expecter) ReadError added in v1.15.1

func (_e *OutputReader_Expecter) ReadError(ctx interface{}) *OutputReader_ReadError_Call

ReadError is a helper method to define mock.On call

  • ctx context.Context

type OutputReader_IsError_Call added in v1.15.1

type OutputReader_IsError_Call struct {
	*mock.Call
}

OutputReader_IsError_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'IsError'

func (*OutputReader_IsError_Call) Return added in v1.15.1

func (*OutputReader_IsError_Call) Run added in v1.15.1

func (*OutputReader_IsError_Call) RunAndReturn added in v1.15.1

type OutputReader_IsFile_Call added in v1.15.1

type OutputReader_IsFile_Call struct {
	*mock.Call
}

OutputReader_IsFile_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'IsFile'

func (*OutputReader_IsFile_Call) Return added in v1.15.1

func (*OutputReader_IsFile_Call) Run added in v1.15.1

func (*OutputReader_IsFile_Call) RunAndReturn added in v1.15.1

type OutputReader_ReadError_Call added in v1.15.1

type OutputReader_ReadError_Call struct {
	*mock.Call
}

OutputReader_ReadError_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'ReadError'

func (*OutputReader_ReadError_Call) Return added in v1.15.1

func (*OutputReader_ReadError_Call) Run added in v1.15.1

func (*OutputReader_ReadError_Call) RunAndReturn added in v1.15.1

type OutputReader_Read_Call added in v1.15.1

type OutputReader_Read_Call struct {
	*mock.Call
}

OutputReader_Read_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Read'

func (*OutputReader_Read_Call) Return added in v1.15.1

func (*OutputReader_Read_Call) Run added in v1.15.1

func (*OutputReader_Read_Call) RunAndReturn added in v1.15.1

type OutputWriter

type OutputWriter struct {
	mock.Mock
}

OutputWriter is an autogenerated mock type for the OutputWriter type

func NewOutputWriter added in v1.15.1

func NewOutputWriter(t interface {
	mock.TestingT
	Cleanup(func())
}) *OutputWriter

NewOutputWriter creates a new instance of OutputWriter. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*OutputWriter) EXPECT added in v1.15.1

func (_m *OutputWriter) EXPECT() *OutputWriter_Expecter

func (*OutputWriter) GetCheckpointPrefix

func (_m *OutputWriter) GetCheckpointPrefix() storage.DataReference

GetCheckpointPrefix provides a mock function with no fields

func (*OutputWriter) GetDeckPath

func (_m *OutputWriter) GetDeckPath() storage.DataReference

GetDeckPath provides a mock function with no fields

func (*OutputWriter) GetErrorPath

func (_m *OutputWriter) GetErrorPath() storage.DataReference

GetErrorPath provides a mock function with no fields

func (*OutputWriter) GetOutputPath

func (_m *OutputWriter) GetOutputPath() storage.DataReference

GetOutputPath provides a mock function with no fields

func (*OutputWriter) GetOutputPrefixPath

func (_m *OutputWriter) GetOutputPrefixPath() storage.DataReference

GetOutputPrefixPath provides a mock function with no fields

func (*OutputWriter) GetPreviousCheckpointsPrefix

func (_m *OutputWriter) GetPreviousCheckpointsPrefix() storage.DataReference

GetPreviousCheckpointsPrefix provides a mock function with no fields

func (*OutputWriter) GetRawOutputPrefix

func (_m *OutputWriter) GetRawOutputPrefix() storage.DataReference

GetRawOutputPrefix provides a mock function with no fields

func (*OutputWriter) Put

func (_m *OutputWriter) Put(ctx context.Context, reader io.OutputReader) error

Put provides a mock function with given fields: ctx, reader

type OutputWriter_Expecter added in v1.15.1

type OutputWriter_Expecter struct {
	// contains filtered or unexported fields
}

func (*OutputWriter_Expecter) GetCheckpointPrefix added in v1.15.1

GetCheckpointPrefix is a helper method to define mock.On call

func (*OutputWriter_Expecter) GetDeckPath added in v1.15.1

GetDeckPath is a helper method to define mock.On call

func (*OutputWriter_Expecter) GetErrorPath added in v1.15.1

GetErrorPath is a helper method to define mock.On call

func (*OutputWriter_Expecter) GetOutputPath added in v1.15.1

GetOutputPath is a helper method to define mock.On call

func (*OutputWriter_Expecter) GetOutputPrefixPath added in v1.15.1

GetOutputPrefixPath is a helper method to define mock.On call

func (*OutputWriter_Expecter) GetPreviousCheckpointsPrefix added in v1.15.1

func (_e *OutputWriter_Expecter) GetPreviousCheckpointsPrefix() *OutputWriter_GetPreviousCheckpointsPrefix_Call

GetPreviousCheckpointsPrefix is a helper method to define mock.On call

func (*OutputWriter_Expecter) GetRawOutputPrefix added in v1.15.1

GetRawOutputPrefix is a helper method to define mock.On call

func (*OutputWriter_Expecter) Put added in v1.15.1

func (_e *OutputWriter_Expecter) Put(ctx interface{}, reader interface{}) *OutputWriter_Put_Call

Put is a helper method to define mock.On call

  • ctx context.Context
  • reader io.OutputReader

type OutputWriter_GetCheckpointPrefix_Call added in v1.15.1

type OutputWriter_GetCheckpointPrefix_Call struct {
	*mock.Call
}

OutputWriter_GetCheckpointPrefix_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetCheckpointPrefix'

func (*OutputWriter_GetCheckpointPrefix_Call) Return added in v1.15.1

func (*OutputWriter_GetCheckpointPrefix_Call) Run added in v1.15.1

func (*OutputWriter_GetCheckpointPrefix_Call) RunAndReturn added in v1.15.1

type OutputWriter_GetDeckPath_Call added in v1.15.1

type OutputWriter_GetDeckPath_Call struct {
	*mock.Call
}

OutputWriter_GetDeckPath_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetDeckPath'

func (*OutputWriter_GetDeckPath_Call) Return added in v1.15.1

func (*OutputWriter_GetDeckPath_Call) Run added in v1.15.1

func (*OutputWriter_GetDeckPath_Call) RunAndReturn added in v1.15.1

type OutputWriter_GetErrorPath_Call added in v1.15.1

type OutputWriter_GetErrorPath_Call struct {
	*mock.Call
}

OutputWriter_GetErrorPath_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetErrorPath'

func (*OutputWriter_GetErrorPath_Call) Return added in v1.15.1

func (*OutputWriter_GetErrorPath_Call) Run added in v1.15.1

func (*OutputWriter_GetErrorPath_Call) RunAndReturn added in v1.15.1

type OutputWriter_GetOutputPath_Call added in v1.15.1

type OutputWriter_GetOutputPath_Call struct {
	*mock.Call
}

OutputWriter_GetOutputPath_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetOutputPath'

func (*OutputWriter_GetOutputPath_Call) Return added in v1.15.1

func (*OutputWriter_GetOutputPath_Call) Run added in v1.15.1

func (*OutputWriter_GetOutputPath_Call) RunAndReturn added in v1.15.1

type OutputWriter_GetOutputPrefixPath_Call added in v1.15.1

type OutputWriter_GetOutputPrefixPath_Call struct {
	*mock.Call
}

OutputWriter_GetOutputPrefixPath_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetOutputPrefixPath'

func (*OutputWriter_GetOutputPrefixPath_Call) Return added in v1.15.1

func (*OutputWriter_GetOutputPrefixPath_Call) Run added in v1.15.1

func (*OutputWriter_GetOutputPrefixPath_Call) RunAndReturn added in v1.15.1

type OutputWriter_GetPreviousCheckpointsPrefix_Call added in v1.15.1

type OutputWriter_GetPreviousCheckpointsPrefix_Call struct {
	*mock.Call
}

OutputWriter_GetPreviousCheckpointsPrefix_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetPreviousCheckpointsPrefix'

func (*OutputWriter_GetPreviousCheckpointsPrefix_Call) Return added in v1.15.1

func (*OutputWriter_GetPreviousCheckpointsPrefix_Call) Run added in v1.15.1

func (*OutputWriter_GetPreviousCheckpointsPrefix_Call) RunAndReturn added in v1.15.1

type OutputWriter_GetRawOutputPrefix_Call added in v1.15.1

type OutputWriter_GetRawOutputPrefix_Call struct {
	*mock.Call
}

OutputWriter_GetRawOutputPrefix_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetRawOutputPrefix'

func (*OutputWriter_GetRawOutputPrefix_Call) Return added in v1.15.1

func (*OutputWriter_GetRawOutputPrefix_Call) Run added in v1.15.1

func (*OutputWriter_GetRawOutputPrefix_Call) RunAndReturn added in v1.15.1

type OutputWriter_Put_Call added in v1.15.1

type OutputWriter_Put_Call struct {
	*mock.Call
}

OutputWriter_Put_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Put'

func (*OutputWriter_Put_Call) Return added in v1.15.1

func (*OutputWriter_Put_Call) Run added in v1.15.1

func (*OutputWriter_Put_Call) RunAndReturn added in v1.15.1

type RawOutputPaths

type RawOutputPaths struct {
	mock.Mock
}

RawOutputPaths is an autogenerated mock type for the RawOutputPaths type

func NewRawOutputPaths added in v1.15.1

func NewRawOutputPaths(t interface {
	mock.TestingT
	Cleanup(func())
}) *RawOutputPaths

NewRawOutputPaths creates a new instance of RawOutputPaths. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*RawOutputPaths) EXPECT added in v1.15.1

func (*RawOutputPaths) GetRawOutputPrefix

func (_m *RawOutputPaths) GetRawOutputPrefix() storage.DataReference

GetRawOutputPrefix provides a mock function with no fields

type RawOutputPaths_Expecter added in v1.15.1

type RawOutputPaths_Expecter struct {
	// contains filtered or unexported fields
}

func (*RawOutputPaths_Expecter) GetRawOutputPrefix added in v1.15.1

GetRawOutputPrefix is a helper method to define mock.On call

type RawOutputPaths_GetRawOutputPrefix_Call added in v1.15.1

type RawOutputPaths_GetRawOutputPrefix_Call struct {
	*mock.Call
}

RawOutputPaths_GetRawOutputPrefix_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetRawOutputPrefix'

func (*RawOutputPaths_GetRawOutputPrefix_Call) Return added in v1.15.1

func (*RawOutputPaths_GetRawOutputPrefix_Call) Run added in v1.15.1

func (*RawOutputPaths_GetRawOutputPrefix_Call) RunAndReturn added in v1.15.1

Jump to