mocks

package
v2.0.9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 25, 2026 License: Apache-2.0, Apache-2.0 Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type GarbageCollectable added in v2.0.1

type GarbageCollectable struct {
	mock.Mock
}

GarbageCollectable is an autogenerated mock type for the GarbageCollectable type

func NewGarbageCollectable added in v2.0.1

func NewGarbageCollectable(t interface {
	mock.TestingT
	Cleanup(func())
}) *GarbageCollectable

NewGarbageCollectable creates a new instance of GarbageCollectable. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*GarbageCollectable) EXPECT added in v2.0.1

func (*GarbageCollectable) GetCompletionTime added in v2.0.1

func (_m *GarbageCollectable) GetCompletionTime(resource client.Object) (time.Time, error)

GetCompletionTime provides a mock function with given fields: resource

func (*GarbageCollectable) IsTerminal added in v2.0.1

func (_m *GarbageCollectable) IsTerminal(ctx context.Context, resource client.Object) (bool, error)

IsTerminal provides a mock function with given fields: ctx, resource

type GarbageCollectable_Expecter added in v2.0.1

type GarbageCollectable_Expecter struct {
	// contains filtered or unexported fields
}

func (*GarbageCollectable_Expecter) GetCompletionTime added in v2.0.1

func (_e *GarbageCollectable_Expecter) GetCompletionTime(resource interface{}) *GarbageCollectable_GetCompletionTime_Call

GetCompletionTime is a helper method to define mock.On call

  • resource client.Object

func (*GarbageCollectable_Expecter) IsTerminal added in v2.0.1

func (_e *GarbageCollectable_Expecter) IsTerminal(ctx interface{}, resource interface{}) *GarbageCollectable_IsTerminal_Call

IsTerminal is a helper method to define mock.On call

  • ctx context.Context
  • resource client.Object

type GarbageCollectable_GetCompletionTime_Call added in v2.0.1

type GarbageCollectable_GetCompletionTime_Call struct {
	*mock.Call
}

GarbageCollectable_GetCompletionTime_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetCompletionTime'

func (*GarbageCollectable_GetCompletionTime_Call) Return added in v2.0.1

func (*GarbageCollectable_GetCompletionTime_Call) Run added in v2.0.1

func (*GarbageCollectable_GetCompletionTime_Call) RunAndReturn added in v2.0.1

type GarbageCollectable_IsTerminal_Call added in v2.0.1

type GarbageCollectable_IsTerminal_Call struct {
	*mock.Call
}

GarbageCollectable_IsTerminal_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'IsTerminal'

func (*GarbageCollectable_IsTerminal_Call) Return added in v2.0.1

func (*GarbageCollectable_IsTerminal_Call) Run added in v2.0.1

func (*GarbageCollectable_IsTerminal_Call) RunAndReturn added in v2.0.1

type Plugin

type Plugin struct {
	mock.Mock
}

Plugin is an autogenerated mock type for the Plugin type

func NewPlugin added in v2.0.1

func NewPlugin(t interface {
	mock.TestingT
	Cleanup(func())
}) *Plugin

NewPlugin creates a new instance of Plugin. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*Plugin) BuildIdentityResource

func (_m *Plugin) BuildIdentityResource(ctx context.Context, taskCtx core.TaskExecutionMetadata) (client.Object, error)

BuildIdentityResource provides a mock function with given fields: ctx, taskCtx

func (*Plugin) BuildResource

func (_m *Plugin) BuildResource(ctx context.Context, taskCtx core.TaskExecutionContext) (client.Object, error)

BuildResource provides a mock function with given fields: ctx, taskCtx

func (*Plugin) EXPECT added in v2.0.1

func (_m *Plugin) EXPECT() *Plugin_Expecter

func (*Plugin) GetCompletionTime added in v2.0.1

func (_m *Plugin) GetCompletionTime(resource client.Object) (time.Time, error)

GetCompletionTime provides a mock function with given fields: resource

func (*Plugin) GetProperties

func (_m *Plugin) GetProperties() k8s.PluginProperties

GetProperties provides a mock function with no fields

func (*Plugin) GetTaskPhase

func (_m *Plugin) GetTaskPhase(ctx context.Context, pluginContext k8s.PluginContext, resource client.Object) (core.PhaseInfo, error)

GetTaskPhase provides a mock function with given fields: ctx, pluginContext, resource

func (*Plugin) IsTerminal added in v2.0.1

func (_m *Plugin) IsTerminal(ctx context.Context, resource client.Object) (bool, error)

IsTerminal provides a mock function with given fields: ctx, resource

type PluginAbortOverride

type PluginAbortOverride struct {
	mock.Mock
}

PluginAbortOverride is an autogenerated mock type for the PluginAbortOverride type

func NewPluginAbortOverride added in v2.0.1

func NewPluginAbortOverride(t interface {
	mock.TestingT
	Cleanup(func())
}) *PluginAbortOverride

NewPluginAbortOverride creates a new instance of PluginAbortOverride. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*PluginAbortOverride) EXPECT added in v2.0.1

func (*PluginAbortOverride) OnAbort

OnAbort provides a mock function with given fields: ctx, tCtx, resource

type PluginAbortOverride_Expecter added in v2.0.1

type PluginAbortOverride_Expecter struct {
	// contains filtered or unexported fields
}

func (*PluginAbortOverride_Expecter) OnAbort added in v2.0.1

func (_e *PluginAbortOverride_Expecter) OnAbort(ctx interface{}, tCtx interface{}, resource interface{}) *PluginAbortOverride_OnAbort_Call

OnAbort is a helper method to define mock.On call

  • ctx context.Context
  • tCtx core.TaskExecutionContext
  • resource client.Object

type PluginAbortOverride_OnAbort_Call added in v2.0.1

type PluginAbortOverride_OnAbort_Call struct {
	*mock.Call
}

PluginAbortOverride_OnAbort_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OnAbort'

func (*PluginAbortOverride_OnAbort_Call) Return added in v2.0.1

func (*PluginAbortOverride_OnAbort_Call) Run added in v2.0.1

func (*PluginAbortOverride_OnAbort_Call) RunAndReturn added in v2.0.1

type PluginContext

type PluginContext struct {
	mock.Mock
}

PluginContext is an autogenerated mock type for the PluginContext type

func NewPluginContext added in v2.0.1

func NewPluginContext(t interface {
	mock.TestingT
	Cleanup(func())
}) *PluginContext

NewPluginContext creates a new instance of PluginContext. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*PluginContext) DataStore

func (_m *PluginContext) DataStore() *storage.DataStore

DataStore provides a mock function with no fields

func (*PluginContext) EXPECT added in v2.0.1

func (_m *PluginContext) EXPECT() *PluginContext_Expecter

func (*PluginContext) InputReader

func (_m *PluginContext) InputReader() io.InputReader

InputReader provides a mock function with no fields

func (*PluginContext) K8sReader

func (_m *PluginContext) K8sReader() client.Reader

K8sReader provides a mock function with no fields

func (*PluginContext) OutputWriter

func (_m *PluginContext) OutputWriter() io.OutputWriter

OutputWriter provides a mock function with no fields

func (*PluginContext) PluginStateReader

func (_m *PluginContext) PluginStateReader() core.PluginStateReader

PluginStateReader provides a mock function with no fields

func (*PluginContext) TaskExecutionMetadata

func (_m *PluginContext) TaskExecutionMetadata() core.TaskExecutionMetadata

TaskExecutionMetadata provides a mock function with no fields

func (*PluginContext) TaskReader

func (_m *PluginContext) TaskReader() core.TaskReader

TaskReader provides a mock function with no fields

type PluginContext_DataStore_Call added in v2.0.1

type PluginContext_DataStore_Call struct {
	*mock.Call
}

PluginContext_DataStore_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'DataStore'

func (*PluginContext_DataStore_Call) Return added in v2.0.1

func (*PluginContext_DataStore_Call) Run added in v2.0.1

func (*PluginContext_DataStore_Call) RunAndReturn added in v2.0.1

type PluginContext_Expecter added in v2.0.1

type PluginContext_Expecter struct {
	// contains filtered or unexported fields
}

func (*PluginContext_Expecter) DataStore added in v2.0.1

DataStore is a helper method to define mock.On call

func (*PluginContext_Expecter) InputReader added in v2.0.1

InputReader is a helper method to define mock.On call

func (*PluginContext_Expecter) K8sReader added in v2.0.1

K8sReader is a helper method to define mock.On call

func (*PluginContext_Expecter) OutputWriter added in v2.0.1

OutputWriter is a helper method to define mock.On call

func (*PluginContext_Expecter) PluginStateReader added in v2.0.1

PluginStateReader is a helper method to define mock.On call

func (*PluginContext_Expecter) TaskExecutionMetadata added in v2.0.1

TaskExecutionMetadata is a helper method to define mock.On call

func (*PluginContext_Expecter) TaskReader added in v2.0.1

TaskReader is a helper method to define mock.On call

type PluginContext_InputReader_Call added in v2.0.1

type PluginContext_InputReader_Call struct {
	*mock.Call
}

PluginContext_InputReader_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'InputReader'

func (*PluginContext_InputReader_Call) Return added in v2.0.1

func (*PluginContext_InputReader_Call) Run added in v2.0.1

func (*PluginContext_InputReader_Call) RunAndReturn added in v2.0.1

type PluginContext_K8sReader_Call added in v2.0.1

type PluginContext_K8sReader_Call struct {
	*mock.Call
}

PluginContext_K8sReader_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'K8sReader'

func (*PluginContext_K8sReader_Call) Return added in v2.0.1

func (*PluginContext_K8sReader_Call) Run added in v2.0.1

func (*PluginContext_K8sReader_Call) RunAndReturn added in v2.0.1

type PluginContext_OutputWriter_Call added in v2.0.1

type PluginContext_OutputWriter_Call struct {
	*mock.Call
}

PluginContext_OutputWriter_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OutputWriter'

func (*PluginContext_OutputWriter_Call) Return added in v2.0.1

func (*PluginContext_OutputWriter_Call) Run added in v2.0.1

func (*PluginContext_OutputWriter_Call) RunAndReturn added in v2.0.1

type PluginContext_PluginStateReader_Call added in v2.0.1

type PluginContext_PluginStateReader_Call struct {
	*mock.Call
}

PluginContext_PluginStateReader_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'PluginStateReader'

func (*PluginContext_PluginStateReader_Call) Return added in v2.0.1

func (*PluginContext_PluginStateReader_Call) Run added in v2.0.1

func (*PluginContext_PluginStateReader_Call) RunAndReturn added in v2.0.1

type PluginContext_TaskExecutionMetadata_Call added in v2.0.1

type PluginContext_TaskExecutionMetadata_Call struct {
	*mock.Call
}

PluginContext_TaskExecutionMetadata_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'TaskExecutionMetadata'

func (*PluginContext_TaskExecutionMetadata_Call) Return added in v2.0.1

func (*PluginContext_TaskExecutionMetadata_Call) Run added in v2.0.1

func (*PluginContext_TaskExecutionMetadata_Call) RunAndReturn added in v2.0.1

type PluginContext_TaskReader_Call added in v2.0.1

type PluginContext_TaskReader_Call struct {
	*mock.Call
}

PluginContext_TaskReader_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'TaskReader'

func (*PluginContext_TaskReader_Call) Return added in v2.0.1

func (*PluginContext_TaskReader_Call) Run added in v2.0.1

func (*PluginContext_TaskReader_Call) RunAndReturn added in v2.0.1

type Plugin_BuildIdentityResource_Call added in v2.0.1

type Plugin_BuildIdentityResource_Call struct {
	*mock.Call
}

Plugin_BuildIdentityResource_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'BuildIdentityResource'

func (*Plugin_BuildIdentityResource_Call) Return added in v2.0.1

func (*Plugin_BuildIdentityResource_Call) Run added in v2.0.1

func (*Plugin_BuildIdentityResource_Call) RunAndReturn added in v2.0.1

type Plugin_BuildResource_Call added in v2.0.1

type Plugin_BuildResource_Call struct {
	*mock.Call
}

Plugin_BuildResource_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'BuildResource'

func (*Plugin_BuildResource_Call) Return added in v2.0.1

func (*Plugin_BuildResource_Call) Run added in v2.0.1

func (*Plugin_BuildResource_Call) RunAndReturn added in v2.0.1

type Plugin_Expecter added in v2.0.1

type Plugin_Expecter struct {
	// contains filtered or unexported fields
}

func (*Plugin_Expecter) BuildIdentityResource added in v2.0.1

func (_e *Plugin_Expecter) BuildIdentityResource(ctx interface{}, taskCtx interface{}) *Plugin_BuildIdentityResource_Call

BuildIdentityResource is a helper method to define mock.On call

  • ctx context.Context
  • taskCtx core.TaskExecutionMetadata

func (*Plugin_Expecter) BuildResource added in v2.0.1

func (_e *Plugin_Expecter) BuildResource(ctx interface{}, taskCtx interface{}) *Plugin_BuildResource_Call

BuildResource is a helper method to define mock.On call

  • ctx context.Context
  • taskCtx core.TaskExecutionContext

func (*Plugin_Expecter) GetCompletionTime added in v2.0.1

func (_e *Plugin_Expecter) GetCompletionTime(resource interface{}) *Plugin_GetCompletionTime_Call

GetCompletionTime is a helper method to define mock.On call

  • resource client.Object

func (*Plugin_Expecter) GetProperties added in v2.0.1

func (_e *Plugin_Expecter) GetProperties() *Plugin_GetProperties_Call

GetProperties is a helper method to define mock.On call

func (*Plugin_Expecter) GetTaskPhase added in v2.0.1

func (_e *Plugin_Expecter) GetTaskPhase(ctx interface{}, pluginContext interface{}, resource interface{}) *Plugin_GetTaskPhase_Call

GetTaskPhase is a helper method to define mock.On call

  • ctx context.Context
  • pluginContext k8s.PluginContext
  • resource client.Object

func (*Plugin_Expecter) IsTerminal added in v2.0.1

func (_e *Plugin_Expecter) IsTerminal(ctx interface{}, resource interface{}) *Plugin_IsTerminal_Call

IsTerminal is a helper method to define mock.On call

  • ctx context.Context
  • resource client.Object

type Plugin_GetCompletionTime_Call added in v2.0.1

type Plugin_GetCompletionTime_Call struct {
	*mock.Call
}

Plugin_GetCompletionTime_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetCompletionTime'

func (*Plugin_GetCompletionTime_Call) Return added in v2.0.1

func (*Plugin_GetCompletionTime_Call) Run added in v2.0.1

func (*Plugin_GetCompletionTime_Call) RunAndReturn added in v2.0.1

type Plugin_GetProperties_Call added in v2.0.1

type Plugin_GetProperties_Call struct {
	*mock.Call
}

Plugin_GetProperties_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetProperties'

func (*Plugin_GetProperties_Call) Return added in v2.0.1

func (*Plugin_GetProperties_Call) Run added in v2.0.1

func (*Plugin_GetProperties_Call) RunAndReturn added in v2.0.1

type Plugin_GetTaskPhase_Call added in v2.0.1

type Plugin_GetTaskPhase_Call struct {
	*mock.Call
}

Plugin_GetTaskPhase_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetTaskPhase'

func (*Plugin_GetTaskPhase_Call) Return added in v2.0.1

func (*Plugin_GetTaskPhase_Call) Run added in v2.0.1

func (_c *Plugin_GetTaskPhase_Call) Run(run func(ctx context.Context, pluginContext k8s.PluginContext, resource client.Object)) *Plugin_GetTaskPhase_Call

func (*Plugin_GetTaskPhase_Call) RunAndReturn added in v2.0.1

type Plugin_IsTerminal_Call added in v2.0.1

type Plugin_IsTerminal_Call struct {
	*mock.Call
}

Plugin_IsTerminal_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'IsTerminal'

func (*Plugin_IsTerminal_Call) Return added in v2.0.1

func (*Plugin_IsTerminal_Call) Run added in v2.0.1

func (_c *Plugin_IsTerminal_Call) Run(run func(ctx context.Context, resource client.Object)) *Plugin_IsTerminal_Call

func (*Plugin_IsTerminal_Call) RunAndReturn added in v2.0.1

type Resource

type Resource struct {
	mock.Mock
}

Resource is an autogenerated mock type for the Resource type

func (*Resource) DeepCopyObject

func (_m *Resource) DeepCopyObject() runtime.Object

DeepCopyObject provides a mock function with given fields:

func (*Resource) GetAnnotations

func (_m *Resource) GetAnnotations() map[string]string

GetAnnotations provides a mock function with given fields:

func (*Resource) GetClusterName

func (_m *Resource) GetClusterName() string

GetClusterName provides a mock function with given fields:

func (*Resource) GetCreationTimestamp

func (_m *Resource) GetCreationTimestamp() v1.Time

GetCreationTimestamp provides a mock function with given fields:

func (*Resource) GetDeletionGracePeriodSeconds

func (_m *Resource) GetDeletionGracePeriodSeconds() *int64

GetDeletionGracePeriodSeconds provides a mock function with given fields:

func (*Resource) GetDeletionTimestamp

func (_m *Resource) GetDeletionTimestamp() *v1.Time

GetDeletionTimestamp provides a mock function with given fields:

func (*Resource) GetFinalizers

func (_m *Resource) GetFinalizers() []string

GetFinalizers provides a mock function with given fields:

func (*Resource) GetGenerateName

func (_m *Resource) GetGenerateName() string

GetGenerateName provides a mock function with given fields:

func (*Resource) GetGeneration

func (_m *Resource) GetGeneration() int64

GetGeneration provides a mock function with given fields:

func (*Resource) GetLabels

func (_m *Resource) GetLabels() map[string]string

GetLabels provides a mock function with given fields:

func (*Resource) GetManagedFields

func (_m *Resource) GetManagedFields() []v1.ManagedFieldsEntry

GetManagedFields provides a mock function with given fields:

func (*Resource) GetName

func (_m *Resource) GetName() string

GetName provides a mock function with given fields:

func (*Resource) GetNamespace

func (_m *Resource) GetNamespace() string

GetNamespace provides a mock function with given fields:

func (*Resource) GetObjectKind

func (_m *Resource) GetObjectKind() schema.ObjectKind

GetObjectKind provides a mock function with given fields:

func (*Resource) GetOwnerReferences

func (_m *Resource) GetOwnerReferences() []v1.OwnerReference

GetOwnerReferences provides a mock function with given fields:

func (*Resource) GetResourceVersion

func (_m *Resource) GetResourceVersion() string

GetResourceVersion provides a mock function with given fields:

func (_m *Resource) GetSelfLink() string

GetSelfLink provides a mock function with given fields:

func (*Resource) GetUID

func (_m *Resource) GetUID() types.UID

GetUID provides a mock function with given fields:

func (*Resource) GroupVersionKind

func (_m *Resource) GroupVersionKind() schema.GroupVersionKind

GroupVersionKind provides a mock function with given fields:

func (*Resource) OnDeepCopyObject

func (_m *Resource) OnDeepCopyObject() *Resource_DeepCopyObject

func (*Resource) OnDeepCopyObjectMatch

func (_m *Resource) OnDeepCopyObjectMatch(matchers ...interface{}) *Resource_DeepCopyObject

func (*Resource) OnGetAnnotations

func (_m *Resource) OnGetAnnotations() *Resource_GetAnnotations

func (*Resource) OnGetAnnotationsMatch

func (_m *Resource) OnGetAnnotationsMatch(matchers ...interface{}) *Resource_GetAnnotations

func (*Resource) OnGetClusterName

func (_m *Resource) OnGetClusterName() *Resource_GetClusterName

func (*Resource) OnGetClusterNameMatch

func (_m *Resource) OnGetClusterNameMatch(matchers ...interface{}) *Resource_GetClusterName

func (*Resource) OnGetCreationTimestamp

func (_m *Resource) OnGetCreationTimestamp() *Resource_GetCreationTimestamp

func (*Resource) OnGetCreationTimestampMatch

func (_m *Resource) OnGetCreationTimestampMatch(matchers ...interface{}) *Resource_GetCreationTimestamp

func (*Resource) OnGetDeletionGracePeriodSeconds

func (_m *Resource) OnGetDeletionGracePeriodSeconds() *Resource_GetDeletionGracePeriodSeconds

func (*Resource) OnGetDeletionGracePeriodSecondsMatch

func (_m *Resource) OnGetDeletionGracePeriodSecondsMatch(matchers ...interface{}) *Resource_GetDeletionGracePeriodSeconds

func (*Resource) OnGetDeletionTimestamp

func (_m *Resource) OnGetDeletionTimestamp() *Resource_GetDeletionTimestamp

func (*Resource) OnGetDeletionTimestampMatch

func (_m *Resource) OnGetDeletionTimestampMatch(matchers ...interface{}) *Resource_GetDeletionTimestamp

func (*Resource) OnGetFinalizers

func (_m *Resource) OnGetFinalizers() *Resource_GetFinalizers

func (*Resource) OnGetFinalizersMatch

func (_m *Resource) OnGetFinalizersMatch(matchers ...interface{}) *Resource_GetFinalizers

func (*Resource) OnGetGenerateName

func (_m *Resource) OnGetGenerateName() *Resource_GetGenerateName

func (*Resource) OnGetGenerateNameMatch

func (_m *Resource) OnGetGenerateNameMatch(matchers ...interface{}) *Resource_GetGenerateName

func (*Resource) OnGetGeneration

func (_m *Resource) OnGetGeneration() *Resource_GetGeneration

func (*Resource) OnGetGenerationMatch

func (_m *Resource) OnGetGenerationMatch(matchers ...interface{}) *Resource_GetGeneration

func (*Resource) OnGetLabels

func (_m *Resource) OnGetLabels() *Resource_GetLabels

func (*Resource) OnGetLabelsMatch

func (_m *Resource) OnGetLabelsMatch(matchers ...interface{}) *Resource_GetLabels

func (*Resource) OnGetManagedFields

func (_m *Resource) OnGetManagedFields() *Resource_GetManagedFields

func (*Resource) OnGetManagedFieldsMatch

func (_m *Resource) OnGetManagedFieldsMatch(matchers ...interface{}) *Resource_GetManagedFields

func (*Resource) OnGetName

func (_m *Resource) OnGetName() *Resource_GetName

func (*Resource) OnGetNameMatch

func (_m *Resource) OnGetNameMatch(matchers ...interface{}) *Resource_GetName

func (*Resource) OnGetNamespace

func (_m *Resource) OnGetNamespace() *Resource_GetNamespace

func (*Resource) OnGetNamespaceMatch

func (_m *Resource) OnGetNamespaceMatch(matchers ...interface{}) *Resource_GetNamespace

func (*Resource) OnGetObjectKind

func (_m *Resource) OnGetObjectKind() *Resource_GetObjectKind

func (*Resource) OnGetObjectKindMatch

func (_m *Resource) OnGetObjectKindMatch(matchers ...interface{}) *Resource_GetObjectKind

func (*Resource) OnGetOwnerReferences

func (_m *Resource) OnGetOwnerReferences() *Resource_GetOwnerReferences

func (*Resource) OnGetOwnerReferencesMatch

func (_m *Resource) OnGetOwnerReferencesMatch(matchers ...interface{}) *Resource_GetOwnerReferences

func (*Resource) OnGetResourceVersion

func (_m *Resource) OnGetResourceVersion() *Resource_GetResourceVersion

func (*Resource) OnGetResourceVersionMatch

func (_m *Resource) OnGetResourceVersionMatch(matchers ...interface{}) *Resource_GetResourceVersion
func (_m *Resource) OnGetSelfLink() *Resource_GetSelfLink

func (*Resource) OnGetSelfLinkMatch

func (_m *Resource) OnGetSelfLinkMatch(matchers ...interface{}) *Resource_GetSelfLink

func (*Resource) OnGetUID

func (_m *Resource) OnGetUID() *Resource_GetUID

func (*Resource) OnGetUIDMatch

func (_m *Resource) OnGetUIDMatch(matchers ...interface{}) *Resource_GetUID

func (*Resource) OnGroupVersionKind

func (_m *Resource) OnGroupVersionKind() *Resource_GroupVersionKind

func (*Resource) OnGroupVersionKindMatch

func (_m *Resource) OnGroupVersionKindMatch(matchers ...interface{}) *Resource_GroupVersionKind

func (*Resource) SetAnnotations

func (_m *Resource) SetAnnotations(annotations map[string]string)

SetAnnotations provides a mock function with given fields: annotations

func (*Resource) SetClusterName

func (_m *Resource) SetClusterName(clusterName string)

SetClusterName provides a mock function with given fields: clusterName

func (*Resource) SetCreationTimestamp

func (_m *Resource) SetCreationTimestamp(timestamp v1.Time)

SetCreationTimestamp provides a mock function with given fields: timestamp

func (*Resource) SetDeletionGracePeriodSeconds

func (_m *Resource) SetDeletionGracePeriodSeconds(_a0 *int64)

SetDeletionGracePeriodSeconds provides a mock function with given fields: _a0

func (*Resource) SetDeletionTimestamp

func (_m *Resource) SetDeletionTimestamp(timestamp *v1.Time)

SetDeletionTimestamp provides a mock function with given fields: timestamp

func (*Resource) SetFinalizers

func (_m *Resource) SetFinalizers(finalizers []string)

SetFinalizers provides a mock function with given fields: finalizers

func (*Resource) SetGenerateName

func (_m *Resource) SetGenerateName(name string)

SetGenerateName provides a mock function with given fields: name

func (*Resource) SetGeneration

func (_m *Resource) SetGeneration(generation int64)

SetGeneration provides a mock function with given fields: generation

func (*Resource) SetGroupVersionKind

func (_m *Resource) SetGroupVersionKind(kind schema.GroupVersionKind)

SetGroupVersionKind provides a mock function with given fields: kind

func (*Resource) SetLabels

func (_m *Resource) SetLabels(labels map[string]string)

SetLabels provides a mock function with given fields: labels

func (*Resource) SetManagedFields

func (_m *Resource) SetManagedFields(managedFields []v1.ManagedFieldsEntry)

SetManagedFields provides a mock function with given fields: managedFields

func (*Resource) SetName

func (_m *Resource) SetName(name string)

SetName provides a mock function with given fields: name

func (*Resource) SetNamespace

func (_m *Resource) SetNamespace(namespace string)

SetNamespace provides a mock function with given fields: namespace

func (*Resource) SetOwnerReferences

func (_m *Resource) SetOwnerReferences(_a0 []v1.OwnerReference)

SetOwnerReferences provides a mock function with given fields: _a0

func (*Resource) SetResourceVersion

func (_m *Resource) SetResourceVersion(version string)

SetResourceVersion provides a mock function with given fields: version

func (_m *Resource) SetSelfLink(selfLink string)

SetSelfLink provides a mock function with given fields: selfLink

func (*Resource) SetUID

func (_m *Resource) SetUID(uid types.UID)

SetUID provides a mock function with given fields: uid

type Resource_DeepCopyObject

type Resource_DeepCopyObject struct {
	*mock.Call
}

func (Resource_DeepCopyObject) Return

type Resource_GetAnnotations

type Resource_GetAnnotations struct {
	*mock.Call
}

func (Resource_GetAnnotations) Return

type Resource_GetClusterName

type Resource_GetClusterName struct {
	*mock.Call
}

func (Resource_GetClusterName) Return

type Resource_GetCreationTimestamp

type Resource_GetCreationTimestamp struct {
	*mock.Call
}

func (Resource_GetCreationTimestamp) Return

type Resource_GetDeletionGracePeriodSeconds

type Resource_GetDeletionGracePeriodSeconds struct {
	*mock.Call
}

func (Resource_GetDeletionGracePeriodSeconds) Return

type Resource_GetDeletionTimestamp

type Resource_GetDeletionTimestamp struct {
	*mock.Call
}

func (Resource_GetDeletionTimestamp) Return

type Resource_GetFinalizers

type Resource_GetFinalizers struct {
	*mock.Call
}

func (Resource_GetFinalizers) Return

type Resource_GetGenerateName

type Resource_GetGenerateName struct {
	*mock.Call
}

func (Resource_GetGenerateName) Return

type Resource_GetGeneration

type Resource_GetGeneration struct {
	*mock.Call
}

func (Resource_GetGeneration) Return

type Resource_GetLabels

type Resource_GetLabels struct {
	*mock.Call
}

func (Resource_GetLabels) Return

func (_m Resource_GetLabels) Return(_a0 map[string]string) *Resource_GetLabels

type Resource_GetManagedFields

type Resource_GetManagedFields struct {
	*mock.Call
}

func (Resource_GetManagedFields) Return

type Resource_GetName

type Resource_GetName struct {
	*mock.Call
}

func (Resource_GetName) Return

func (_m Resource_GetName) Return(_a0 string) *Resource_GetName

type Resource_GetNamespace

type Resource_GetNamespace struct {
	*mock.Call
}

func (Resource_GetNamespace) Return

type Resource_GetObjectKind

type Resource_GetObjectKind struct {
	*mock.Call
}

func (Resource_GetObjectKind) Return

type Resource_GetOwnerReferences

type Resource_GetOwnerReferences struct {
	*mock.Call
}

func (Resource_GetOwnerReferences) Return

type Resource_GetResourceVersion

type Resource_GetResourceVersion struct {
	*mock.Call
}

func (Resource_GetResourceVersion) Return

type Resource_GetSelfLink struct {
	*mock.Call
}

func (Resource_GetSelfLink) Return

type Resource_GetUID

type Resource_GetUID struct {
	*mock.Call
}

func (Resource_GetUID) Return

func (_m Resource_GetUID) Return(_a0 types.UID) *Resource_GetUID

type Resource_GroupVersionKind

type Resource_GroupVersionKind struct {
	*mock.Call
}

func (Resource_GroupVersionKind) Return

Jump to