Documentation
¶
Index ¶
- type CheckpointPaths
- type CheckpointPaths_Expecter
- type CheckpointPaths_GetCheckpointPrefix_Call
- func (_c *CheckpointPaths_GetCheckpointPrefix_Call) Return(_a0 storage.DataReference) *CheckpointPaths_GetCheckpointPrefix_Call
- func (_c *CheckpointPaths_GetCheckpointPrefix_Call) Run(run func()) *CheckpointPaths_GetCheckpointPrefix_Call
- func (_c *CheckpointPaths_GetCheckpointPrefix_Call) RunAndReturn(run func() storage.DataReference) *CheckpointPaths_GetCheckpointPrefix_Call
- type CheckpointPaths_GetPreviousCheckpointsPrefix_Call
- func (_c *CheckpointPaths_GetPreviousCheckpointsPrefix_Call) Return(_a0 storage.DataReference) *CheckpointPaths_GetPreviousCheckpointsPrefix_Call
- func (_c *CheckpointPaths_GetPreviousCheckpointsPrefix_Call) Run(run func()) *CheckpointPaths_GetPreviousCheckpointsPrefix_Call
- func (_c *CheckpointPaths_GetPreviousCheckpointsPrefix_Call) RunAndReturn(run func() storage.DataReference) *CheckpointPaths_GetPreviousCheckpointsPrefix_Call
- type ErrorReader
- type ErrorReader_Expecter
- type ErrorReader_IsError_Call
- func (_c *ErrorReader_IsError_Call) Return(_a0 bool, _a1 error) *ErrorReader_IsError_Call
- func (_c *ErrorReader_IsError_Call) Run(run func(ctx context.Context)) *ErrorReader_IsError_Call
- func (_c *ErrorReader_IsError_Call) RunAndReturn(run func(context.Context) (bool, error)) *ErrorReader_IsError_Call
- type ErrorReader_ReadError_Call
- func (_c *ErrorReader_ReadError_Call) Return(_a0 io.ExecutionError, _a1 error) *ErrorReader_ReadError_Call
- func (_c *ErrorReader_ReadError_Call) Run(run func(ctx context.Context)) *ErrorReader_ReadError_Call
- func (_c *ErrorReader_ReadError_Call) RunAndReturn(run func(context.Context) (io.ExecutionError, error)) *ErrorReader_ReadError_Call
- type InputFilePaths
- type InputFilePaths_Expecter
- type InputFilePaths_GetInputPath_Call
- func (_c *InputFilePaths_GetInputPath_Call) Return(_a0 storage.DataReference) *InputFilePaths_GetInputPath_Call
- func (_c *InputFilePaths_GetInputPath_Call) Run(run func()) *InputFilePaths_GetInputPath_Call
- func (_c *InputFilePaths_GetInputPath_Call) RunAndReturn(run func() storage.DataReference) *InputFilePaths_GetInputPath_Call
- type InputFilePaths_GetInputPrefixPath_Call
- func (_c *InputFilePaths_GetInputPrefixPath_Call) Return(_a0 storage.DataReference) *InputFilePaths_GetInputPrefixPath_Call
- func (_c *InputFilePaths_GetInputPrefixPath_Call) Run(run func()) *InputFilePaths_GetInputPrefixPath_Call
- func (_c *InputFilePaths_GetInputPrefixPath_Call) RunAndReturn(run func() storage.DataReference) *InputFilePaths_GetInputPrefixPath_Call
- type InputReader
- type InputReader_Expecter
- type InputReader_GetInputPath_Call
- func (_c *InputReader_GetInputPath_Call) Return(_a0 storage.DataReference) *InputReader_GetInputPath_Call
- func (_c *InputReader_GetInputPath_Call) Run(run func()) *InputReader_GetInputPath_Call
- func (_c *InputReader_GetInputPath_Call) RunAndReturn(run func() storage.DataReference) *InputReader_GetInputPath_Call
- type InputReader_GetInputPrefixPath_Call
- func (_c *InputReader_GetInputPrefixPath_Call) Return(_a0 storage.DataReference) *InputReader_GetInputPrefixPath_Call
- func (_c *InputReader_GetInputPrefixPath_Call) Run(run func()) *InputReader_GetInputPrefixPath_Call
- func (_c *InputReader_GetInputPrefixPath_Call) RunAndReturn(run func() storage.DataReference) *InputReader_GetInputPrefixPath_Call
- type InputReader_Get_Call
- func (_c *InputReader_Get_Call) Return(_a0 *core.LiteralMap, _a1 error) *InputReader_Get_Call
- func (_c *InputReader_Get_Call) Run(run func(ctx context.Context)) *InputReader_Get_Call
- func (_c *InputReader_Get_Call) RunAndReturn(run func(context.Context) (*core.LiteralMap, error)) *InputReader_Get_Call
- type OutputDataSandbox
- func (_m *OutputDataSandbox) GetRawOutputPrefix() storage.DataReference
- func (_m *OutputDataSandbox) OnGetOutputDataSandboxPath() *OutputDataSandbox_GetOutputDataSandboxPath
- func (_m *OutputDataSandbox) OnGetOutputDataSandboxPathMatch(matchers ...interface{}) *OutputDataSandbox_GetOutputDataSandboxPath
- type OutputDataSandbox_GetOutputDataSandboxPath
- type OutputFilePaths
- func (_m *OutputFilePaths) EXPECT() *OutputFilePaths_Expecter
- func (_m *OutputFilePaths) GetCheckpointPrefix() storage.DataReference
- func (_m *OutputFilePaths) GetDeckPath() storage.DataReference
- func (_m *OutputFilePaths) GetErrorPath() storage.DataReference
- func (_m *OutputFilePaths) GetOutputPath() storage.DataReference
- func (_m *OutputFilePaths) GetOutputPrefixPath() storage.DataReference
- func (_m *OutputFilePaths) GetPreviousCheckpointsPrefix() storage.DataReference
- func (_m *OutputFilePaths) GetRawOutputPrefix() storage.DataReference
- type OutputFilePaths_Expecter
- func (_e *OutputFilePaths_Expecter) GetCheckpointPrefix() *OutputFilePaths_GetCheckpointPrefix_Call
- func (_e *OutputFilePaths_Expecter) GetDeckPath() *OutputFilePaths_GetDeckPath_Call
- func (_e *OutputFilePaths_Expecter) GetErrorPath() *OutputFilePaths_GetErrorPath_Call
- func (_e *OutputFilePaths_Expecter) GetOutputPath() *OutputFilePaths_GetOutputPath_Call
- func (_e *OutputFilePaths_Expecter) GetOutputPrefixPath() *OutputFilePaths_GetOutputPrefixPath_Call
- func (_e *OutputFilePaths_Expecter) GetPreviousCheckpointsPrefix() *OutputFilePaths_GetPreviousCheckpointsPrefix_Call
- func (_e *OutputFilePaths_Expecter) GetRawOutputPrefix() *OutputFilePaths_GetRawOutputPrefix_Call
- type OutputFilePaths_GetCheckpointPrefix_Call
- func (_c *OutputFilePaths_GetCheckpointPrefix_Call) Return(_a0 storage.DataReference) *OutputFilePaths_GetCheckpointPrefix_Call
- func (_c *OutputFilePaths_GetCheckpointPrefix_Call) Run(run func()) *OutputFilePaths_GetCheckpointPrefix_Call
- func (_c *OutputFilePaths_GetCheckpointPrefix_Call) RunAndReturn(run func() storage.DataReference) *OutputFilePaths_GetCheckpointPrefix_Call
- type OutputFilePaths_GetDeckPath_Call
- func (_c *OutputFilePaths_GetDeckPath_Call) Return(_a0 storage.DataReference) *OutputFilePaths_GetDeckPath_Call
- func (_c *OutputFilePaths_GetDeckPath_Call) Run(run func()) *OutputFilePaths_GetDeckPath_Call
- func (_c *OutputFilePaths_GetDeckPath_Call) RunAndReturn(run func() storage.DataReference) *OutputFilePaths_GetDeckPath_Call
- type OutputFilePaths_GetErrorPath_Call
- func (_c *OutputFilePaths_GetErrorPath_Call) Return(_a0 storage.DataReference) *OutputFilePaths_GetErrorPath_Call
- func (_c *OutputFilePaths_GetErrorPath_Call) Run(run func()) *OutputFilePaths_GetErrorPath_Call
- func (_c *OutputFilePaths_GetErrorPath_Call) RunAndReturn(run func() storage.DataReference) *OutputFilePaths_GetErrorPath_Call
- type OutputFilePaths_GetOutputPath_Call
- func (_c *OutputFilePaths_GetOutputPath_Call) Return(_a0 storage.DataReference) *OutputFilePaths_GetOutputPath_Call
- func (_c *OutputFilePaths_GetOutputPath_Call) Run(run func()) *OutputFilePaths_GetOutputPath_Call
- func (_c *OutputFilePaths_GetOutputPath_Call) RunAndReturn(run func() storage.DataReference) *OutputFilePaths_GetOutputPath_Call
- type OutputFilePaths_GetOutputPrefixPath_Call
- func (_c *OutputFilePaths_GetOutputPrefixPath_Call) Return(_a0 storage.DataReference) *OutputFilePaths_GetOutputPrefixPath_Call
- func (_c *OutputFilePaths_GetOutputPrefixPath_Call) Run(run func()) *OutputFilePaths_GetOutputPrefixPath_Call
- func (_c *OutputFilePaths_GetOutputPrefixPath_Call) RunAndReturn(run func() storage.DataReference) *OutputFilePaths_GetOutputPrefixPath_Call
- type OutputFilePaths_GetPreviousCheckpointsPrefix_Call
- func (_c *OutputFilePaths_GetPreviousCheckpointsPrefix_Call) Return(_a0 storage.DataReference) *OutputFilePaths_GetPreviousCheckpointsPrefix_Call
- func (_c *OutputFilePaths_GetPreviousCheckpointsPrefix_Call) Run(run func()) *OutputFilePaths_GetPreviousCheckpointsPrefix_Call
- func (_c *OutputFilePaths_GetPreviousCheckpointsPrefix_Call) RunAndReturn(run func() storage.DataReference) *OutputFilePaths_GetPreviousCheckpointsPrefix_Call
- type OutputFilePaths_GetRawOutputPrefix_Call
- func (_c *OutputFilePaths_GetRawOutputPrefix_Call) Return(_a0 storage.DataReference) *OutputFilePaths_GetRawOutputPrefix_Call
- func (_c *OutputFilePaths_GetRawOutputPrefix_Call) Run(run func()) *OutputFilePaths_GetRawOutputPrefix_Call
- func (_c *OutputFilePaths_GetRawOutputPrefix_Call) RunAndReturn(run func() storage.DataReference) *OutputFilePaths_GetRawOutputPrefix_Call
- type OutputReader
- func (_m *OutputReader) DeckExists(ctx context.Context) (bool, error)
- func (_m *OutputReader) EXPECT() *OutputReader_Expecter
- func (_m *OutputReader) Exists(ctx context.Context) (bool, error)
- func (_m *OutputReader) IsError(ctx context.Context) (bool, error)
- func (_m *OutputReader) IsFile(ctx context.Context) bool
- func (_m *OutputReader) Read(ctx context.Context) (*core.LiteralMap, *io.ExecutionError, error)
- func (_m *OutputReader) ReadError(ctx context.Context) (io.ExecutionError, error)
- type OutputReader_DeckExists_Call
- func (_c *OutputReader_DeckExists_Call) Return(_a0 bool, _a1 error) *OutputReader_DeckExists_Call
- func (_c *OutputReader_DeckExists_Call) Run(run func(ctx context.Context)) *OutputReader_DeckExists_Call
- func (_c *OutputReader_DeckExists_Call) RunAndReturn(run func(context.Context) (bool, error)) *OutputReader_DeckExists_Call
- type OutputReader_Exists_Call
- func (_c *OutputReader_Exists_Call) Return(_a0 bool, _a1 error) *OutputReader_Exists_Call
- func (_c *OutputReader_Exists_Call) Run(run func(ctx context.Context)) *OutputReader_Exists_Call
- func (_c *OutputReader_Exists_Call) RunAndReturn(run func(context.Context) (bool, error)) *OutputReader_Exists_Call
- type OutputReader_Expecter
- func (_e *OutputReader_Expecter) DeckExists(ctx interface{}) *OutputReader_DeckExists_Call
- func (_e *OutputReader_Expecter) Exists(ctx interface{}) *OutputReader_Exists_Call
- func (_e *OutputReader_Expecter) IsError(ctx interface{}) *OutputReader_IsError_Call
- func (_e *OutputReader_Expecter) IsFile(ctx interface{}) *OutputReader_IsFile_Call
- func (_e *OutputReader_Expecter) Read(ctx interface{}) *OutputReader_Read_Call
- func (_e *OutputReader_Expecter) ReadError(ctx interface{}) *OutputReader_ReadError_Call
- type OutputReader_IsError_Call
- func (_c *OutputReader_IsError_Call) Return(_a0 bool, _a1 error) *OutputReader_IsError_Call
- func (_c *OutputReader_IsError_Call) Run(run func(ctx context.Context)) *OutputReader_IsError_Call
- func (_c *OutputReader_IsError_Call) RunAndReturn(run func(context.Context) (bool, error)) *OutputReader_IsError_Call
- type OutputReader_IsFile_Call
- type OutputReader_ReadError_Call
- func (_c *OutputReader_ReadError_Call) Return(_a0 io.ExecutionError, _a1 error) *OutputReader_ReadError_Call
- func (_c *OutputReader_ReadError_Call) Run(run func(ctx context.Context)) *OutputReader_ReadError_Call
- func (_c *OutputReader_ReadError_Call) RunAndReturn(run func(context.Context) (io.ExecutionError, error)) *OutputReader_ReadError_Call
- type OutputReader_Read_Call
- func (_c *OutputReader_Read_Call) Return(_a0 *core.LiteralMap, _a1 *io.ExecutionError, _a2 error) *OutputReader_Read_Call
- func (_c *OutputReader_Read_Call) Run(run func(ctx context.Context)) *OutputReader_Read_Call
- func (_c *OutputReader_Read_Call) RunAndReturn(run func(context.Context) (*core.LiteralMap, *io.ExecutionError, error)) *OutputReader_Read_Call
- type OutputWriter
- func (_m *OutputWriter) EXPECT() *OutputWriter_Expecter
- func (_m *OutputWriter) GetCheckpointPrefix() storage.DataReference
- func (_m *OutputWriter) GetDeckPath() storage.DataReference
- func (_m *OutputWriter) GetErrorPath() storage.DataReference
- func (_m *OutputWriter) GetOutputPath() storage.DataReference
- func (_m *OutputWriter) GetOutputPrefixPath() storage.DataReference
- func (_m *OutputWriter) GetPreviousCheckpointsPrefix() storage.DataReference
- func (_m *OutputWriter) GetRawOutputPrefix() storage.DataReference
- func (_m *OutputWriter) Put(ctx context.Context, reader io.OutputReader) error
- type OutputWriter_Expecter
- func (_e *OutputWriter_Expecter) GetCheckpointPrefix() *OutputWriter_GetCheckpointPrefix_Call
- func (_e *OutputWriter_Expecter) GetDeckPath() *OutputWriter_GetDeckPath_Call
- func (_e *OutputWriter_Expecter) GetErrorPath() *OutputWriter_GetErrorPath_Call
- func (_e *OutputWriter_Expecter) GetOutputPath() *OutputWriter_GetOutputPath_Call
- func (_e *OutputWriter_Expecter) GetOutputPrefixPath() *OutputWriter_GetOutputPrefixPath_Call
- func (_e *OutputWriter_Expecter) GetPreviousCheckpointsPrefix() *OutputWriter_GetPreviousCheckpointsPrefix_Call
- func (_e *OutputWriter_Expecter) GetRawOutputPrefix() *OutputWriter_GetRawOutputPrefix_Call
- func (_e *OutputWriter_Expecter) Put(ctx interface{}, reader interface{}) *OutputWriter_Put_Call
- type OutputWriter_GetCheckpointPrefix_Call
- func (_c *OutputWriter_GetCheckpointPrefix_Call) Return(_a0 storage.DataReference) *OutputWriter_GetCheckpointPrefix_Call
- func (_c *OutputWriter_GetCheckpointPrefix_Call) Run(run func()) *OutputWriter_GetCheckpointPrefix_Call
- func (_c *OutputWriter_GetCheckpointPrefix_Call) RunAndReturn(run func() storage.DataReference) *OutputWriter_GetCheckpointPrefix_Call
- type OutputWriter_GetDeckPath_Call
- func (_c *OutputWriter_GetDeckPath_Call) Return(_a0 storage.DataReference) *OutputWriter_GetDeckPath_Call
- func (_c *OutputWriter_GetDeckPath_Call) Run(run func()) *OutputWriter_GetDeckPath_Call
- func (_c *OutputWriter_GetDeckPath_Call) RunAndReturn(run func() storage.DataReference) *OutputWriter_GetDeckPath_Call
- type OutputWriter_GetErrorPath_Call
- func (_c *OutputWriter_GetErrorPath_Call) Return(_a0 storage.DataReference) *OutputWriter_GetErrorPath_Call
- func (_c *OutputWriter_GetErrorPath_Call) Run(run func()) *OutputWriter_GetErrorPath_Call
- func (_c *OutputWriter_GetErrorPath_Call) RunAndReturn(run func() storage.DataReference) *OutputWriter_GetErrorPath_Call
- type OutputWriter_GetOutputPath_Call
- func (_c *OutputWriter_GetOutputPath_Call) Return(_a0 storage.DataReference) *OutputWriter_GetOutputPath_Call
- func (_c *OutputWriter_GetOutputPath_Call) Run(run func()) *OutputWriter_GetOutputPath_Call
- func (_c *OutputWriter_GetOutputPath_Call) RunAndReturn(run func() storage.DataReference) *OutputWriter_GetOutputPath_Call
- type OutputWriter_GetOutputPrefixPath_Call
- func (_c *OutputWriter_GetOutputPrefixPath_Call) Return(_a0 storage.DataReference) *OutputWriter_GetOutputPrefixPath_Call
- func (_c *OutputWriter_GetOutputPrefixPath_Call) Run(run func()) *OutputWriter_GetOutputPrefixPath_Call
- func (_c *OutputWriter_GetOutputPrefixPath_Call) RunAndReturn(run func() storage.DataReference) *OutputWriter_GetOutputPrefixPath_Call
- type OutputWriter_GetPreviousCheckpointsPrefix_Call
- func (_c *OutputWriter_GetPreviousCheckpointsPrefix_Call) Return(_a0 storage.DataReference) *OutputWriter_GetPreviousCheckpointsPrefix_Call
- func (_c *OutputWriter_GetPreviousCheckpointsPrefix_Call) Run(run func()) *OutputWriter_GetPreviousCheckpointsPrefix_Call
- func (_c *OutputWriter_GetPreviousCheckpointsPrefix_Call) RunAndReturn(run func() storage.DataReference) *OutputWriter_GetPreviousCheckpointsPrefix_Call
- type OutputWriter_GetRawOutputPrefix_Call
- func (_c *OutputWriter_GetRawOutputPrefix_Call) Return(_a0 storage.DataReference) *OutputWriter_GetRawOutputPrefix_Call
- func (_c *OutputWriter_GetRawOutputPrefix_Call) Run(run func()) *OutputWriter_GetRawOutputPrefix_Call
- func (_c *OutputWriter_GetRawOutputPrefix_Call) RunAndReturn(run func() storage.DataReference) *OutputWriter_GetRawOutputPrefix_Call
- type OutputWriter_Put_Call
- func (_c *OutputWriter_Put_Call) Return(_a0 error) *OutputWriter_Put_Call
- func (_c *OutputWriter_Put_Call) Run(run func(ctx context.Context, reader io.OutputReader)) *OutputWriter_Put_Call
- func (_c *OutputWriter_Put_Call) RunAndReturn(run func(context.Context, io.OutputReader) error) *OutputWriter_Put_Call
- type RawOutputPaths
- type RawOutputPaths_Expecter
- type RawOutputPaths_GetRawOutputPrefix_Call
- func (_c *RawOutputPaths_GetRawOutputPrefix_Call) Return(_a0 storage.DataReference) *RawOutputPaths_GetRawOutputPrefix_Call
- func (_c *RawOutputPaths_GetRawOutputPrefix_Call) Run(run func()) *RawOutputPaths_GetRawOutputPrefix_Call
- func (_c *RawOutputPaths_GetRawOutputPrefix_Call) RunAndReturn(run func() storage.DataReference) *RawOutputPaths_GetRawOutputPrefix_Call
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CheckpointPaths ¶
CheckpointPaths is an autogenerated mock type for the CheckpointPaths type
func NewCheckpointPaths ¶ added in v1.15.1
func NewCheckpointPaths(t interface {
mock.TestingT
Cleanup(func())
}) *CheckpointPaths
NewCheckpointPaths creates a new instance of CheckpointPaths. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*CheckpointPaths) EXPECT ¶ added in v1.15.1
func (_m *CheckpointPaths) EXPECT() *CheckpointPaths_Expecter
func (*CheckpointPaths) GetCheckpointPrefix ¶
func (_m *CheckpointPaths) GetCheckpointPrefix() storage.DataReference
GetCheckpointPrefix provides a mock function with no fields
func (*CheckpointPaths) GetPreviousCheckpointsPrefix ¶
func (_m *CheckpointPaths) GetPreviousCheckpointsPrefix() storage.DataReference
GetPreviousCheckpointsPrefix provides a mock function with no fields
type CheckpointPaths_Expecter ¶ added in v1.15.1
type CheckpointPaths_Expecter struct {
// contains filtered or unexported fields
}
func (*CheckpointPaths_Expecter) GetCheckpointPrefix ¶ added in v1.15.1
func (_e *CheckpointPaths_Expecter) GetCheckpointPrefix() *CheckpointPaths_GetCheckpointPrefix_Call
GetCheckpointPrefix is a helper method to define mock.On call
func (*CheckpointPaths_Expecter) GetPreviousCheckpointsPrefix ¶ added in v1.15.1
func (_e *CheckpointPaths_Expecter) GetPreviousCheckpointsPrefix() *CheckpointPaths_GetPreviousCheckpointsPrefix_Call
GetPreviousCheckpointsPrefix is a helper method to define mock.On call
type CheckpointPaths_GetCheckpointPrefix_Call ¶ added in v1.15.1
CheckpointPaths_GetCheckpointPrefix_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetCheckpointPrefix'
func (*CheckpointPaths_GetCheckpointPrefix_Call) Return ¶ added in v1.15.1
func (_c *CheckpointPaths_GetCheckpointPrefix_Call) Return(_a0 storage.DataReference) *CheckpointPaths_GetCheckpointPrefix_Call
func (*CheckpointPaths_GetCheckpointPrefix_Call) Run ¶ added in v1.15.1
func (_c *CheckpointPaths_GetCheckpointPrefix_Call) Run(run func()) *CheckpointPaths_GetCheckpointPrefix_Call
func (*CheckpointPaths_GetCheckpointPrefix_Call) RunAndReturn ¶ added in v1.15.1
func (_c *CheckpointPaths_GetCheckpointPrefix_Call) RunAndReturn(run func() storage.DataReference) *CheckpointPaths_GetCheckpointPrefix_Call
type CheckpointPaths_GetPreviousCheckpointsPrefix_Call ¶ added in v1.15.1
CheckpointPaths_GetPreviousCheckpointsPrefix_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetPreviousCheckpointsPrefix'
func (*CheckpointPaths_GetPreviousCheckpointsPrefix_Call) Run ¶ added in v1.15.1
func (_c *CheckpointPaths_GetPreviousCheckpointsPrefix_Call) Run(run func()) *CheckpointPaths_GetPreviousCheckpointsPrefix_Call
func (*CheckpointPaths_GetPreviousCheckpointsPrefix_Call) RunAndReturn ¶ added in v1.15.1
func (_c *CheckpointPaths_GetPreviousCheckpointsPrefix_Call) RunAndReturn(run func() storage.DataReference) *CheckpointPaths_GetPreviousCheckpointsPrefix_Call
type ErrorReader ¶ added in v1.14.0
ErrorReader is an autogenerated mock type for the ErrorReader type
func NewErrorReader ¶ added in v1.15.1
func NewErrorReader(t interface {
mock.TestingT
Cleanup(func())
}) *ErrorReader
NewErrorReader creates a new instance of ErrorReader. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*ErrorReader) EXPECT ¶ added in v1.15.1
func (_m *ErrorReader) EXPECT() *ErrorReader_Expecter
func (*ErrorReader) IsError ¶ added in v1.14.0
func (_m *ErrorReader) IsError(ctx context.Context) (bool, error)
IsError provides a mock function with given fields: ctx
func (*ErrorReader) ReadError ¶ added in v1.14.0
func (_m *ErrorReader) ReadError(ctx context.Context) (io.ExecutionError, error)
ReadError provides a mock function with given fields: ctx
type ErrorReader_Expecter ¶ added in v1.15.1
type ErrorReader_Expecter struct {
// contains filtered or unexported fields
}
func (*ErrorReader_Expecter) IsError ¶ added in v1.15.1
func (_e *ErrorReader_Expecter) IsError(ctx interface{}) *ErrorReader_IsError_Call
IsError is a helper method to define mock.On call
- ctx context.Context
func (*ErrorReader_Expecter) ReadError ¶ added in v1.15.1
func (_e *ErrorReader_Expecter) ReadError(ctx interface{}) *ErrorReader_ReadError_Call
ReadError is a helper method to define mock.On call
- ctx context.Context
type ErrorReader_IsError_Call ¶ added in v1.15.1
ErrorReader_IsError_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'IsError'
func (*ErrorReader_IsError_Call) Return ¶ added in v1.15.1
func (_c *ErrorReader_IsError_Call) Return(_a0 bool, _a1 error) *ErrorReader_IsError_Call
func (*ErrorReader_IsError_Call) Run ¶ added in v1.15.1
func (_c *ErrorReader_IsError_Call) Run(run func(ctx context.Context)) *ErrorReader_IsError_Call
func (*ErrorReader_IsError_Call) RunAndReturn ¶ added in v1.15.1
func (_c *ErrorReader_IsError_Call) RunAndReturn(run func(context.Context) (bool, error)) *ErrorReader_IsError_Call
type ErrorReader_ReadError_Call ¶ added in v1.15.1
ErrorReader_ReadError_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'ReadError'
func (*ErrorReader_ReadError_Call) Return ¶ added in v1.15.1
func (_c *ErrorReader_ReadError_Call) Return(_a0 io.ExecutionError, _a1 error) *ErrorReader_ReadError_Call
func (*ErrorReader_ReadError_Call) Run ¶ added in v1.15.1
func (_c *ErrorReader_ReadError_Call) Run(run func(ctx context.Context)) *ErrorReader_ReadError_Call
func (*ErrorReader_ReadError_Call) RunAndReturn ¶ added in v1.15.1
func (_c *ErrorReader_ReadError_Call) RunAndReturn(run func(context.Context) (io.ExecutionError, error)) *ErrorReader_ReadError_Call
type InputFilePaths ¶
InputFilePaths is an autogenerated mock type for the InputFilePaths type
func NewInputFilePaths ¶ added in v1.15.1
func NewInputFilePaths(t interface {
mock.TestingT
Cleanup(func())
}) *InputFilePaths
NewInputFilePaths creates a new instance of InputFilePaths. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*InputFilePaths) EXPECT ¶ added in v1.15.1
func (_m *InputFilePaths) EXPECT() *InputFilePaths_Expecter
func (*InputFilePaths) GetInputPath ¶
func (_m *InputFilePaths) GetInputPath() storage.DataReference
GetInputPath provides a mock function with no fields
func (*InputFilePaths) GetInputPrefixPath ¶
func (_m *InputFilePaths) GetInputPrefixPath() storage.DataReference
GetInputPrefixPath provides a mock function with no fields
type InputFilePaths_Expecter ¶ added in v1.15.1
type InputFilePaths_Expecter struct {
// contains filtered or unexported fields
}
func (*InputFilePaths_Expecter) GetInputPath ¶ added in v1.15.1
func (_e *InputFilePaths_Expecter) GetInputPath() *InputFilePaths_GetInputPath_Call
GetInputPath is a helper method to define mock.On call
func (*InputFilePaths_Expecter) GetInputPrefixPath ¶ added in v1.15.1
func (_e *InputFilePaths_Expecter) GetInputPrefixPath() *InputFilePaths_GetInputPrefixPath_Call
GetInputPrefixPath is a helper method to define mock.On call
type InputFilePaths_GetInputPath_Call ¶ added in v1.15.1
InputFilePaths_GetInputPath_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetInputPath'
func (*InputFilePaths_GetInputPath_Call) Return ¶ added in v1.15.1
func (_c *InputFilePaths_GetInputPath_Call) Return(_a0 storage.DataReference) *InputFilePaths_GetInputPath_Call
func (*InputFilePaths_GetInputPath_Call) Run ¶ added in v1.15.1
func (_c *InputFilePaths_GetInputPath_Call) Run(run func()) *InputFilePaths_GetInputPath_Call
func (*InputFilePaths_GetInputPath_Call) RunAndReturn ¶ added in v1.15.1
func (_c *InputFilePaths_GetInputPath_Call) RunAndReturn(run func() storage.DataReference) *InputFilePaths_GetInputPath_Call
type InputFilePaths_GetInputPrefixPath_Call ¶ added in v1.15.1
InputFilePaths_GetInputPrefixPath_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetInputPrefixPath'
func (*InputFilePaths_GetInputPrefixPath_Call) Return ¶ added in v1.15.1
func (_c *InputFilePaths_GetInputPrefixPath_Call) Return(_a0 storage.DataReference) *InputFilePaths_GetInputPrefixPath_Call
func (*InputFilePaths_GetInputPrefixPath_Call) Run ¶ added in v1.15.1
func (_c *InputFilePaths_GetInputPrefixPath_Call) Run(run func()) *InputFilePaths_GetInputPrefixPath_Call
func (*InputFilePaths_GetInputPrefixPath_Call) RunAndReturn ¶ added in v1.15.1
func (_c *InputFilePaths_GetInputPrefixPath_Call) RunAndReturn(run func() storage.DataReference) *InputFilePaths_GetInputPrefixPath_Call
type InputReader ¶
InputReader is an autogenerated mock type for the InputReader type
func NewInputReader ¶ added in v1.15.1
func NewInputReader(t interface {
mock.TestingT
Cleanup(func())
}) *InputReader
NewInputReader creates a new instance of InputReader. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*InputReader) EXPECT ¶ added in v1.15.1
func (_m *InputReader) EXPECT() *InputReader_Expecter
func (*InputReader) Get ¶
func (_m *InputReader) Get(ctx context.Context) (*core.LiteralMap, error)
Get provides a mock function with given fields: ctx
func (*InputReader) GetInputPath ¶
func (_m *InputReader) GetInputPath() storage.DataReference
GetInputPath provides a mock function with no fields
func (*InputReader) GetInputPrefixPath ¶
func (_m *InputReader) GetInputPrefixPath() storage.DataReference
GetInputPrefixPath provides a mock function with no fields
type InputReader_Expecter ¶ added in v1.15.1
type InputReader_Expecter struct {
// contains filtered or unexported fields
}
func (*InputReader_Expecter) Get ¶ added in v1.15.1
func (_e *InputReader_Expecter) Get(ctx interface{}) *InputReader_Get_Call
Get is a helper method to define mock.On call
- ctx context.Context
func (*InputReader_Expecter) GetInputPath ¶ added in v1.15.1
func (_e *InputReader_Expecter) GetInputPath() *InputReader_GetInputPath_Call
GetInputPath is a helper method to define mock.On call
func (*InputReader_Expecter) GetInputPrefixPath ¶ added in v1.15.1
func (_e *InputReader_Expecter) GetInputPrefixPath() *InputReader_GetInputPrefixPath_Call
GetInputPrefixPath is a helper method to define mock.On call
type InputReader_GetInputPath_Call ¶ added in v1.15.1
InputReader_GetInputPath_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetInputPath'
func (*InputReader_GetInputPath_Call) Return ¶ added in v1.15.1
func (_c *InputReader_GetInputPath_Call) Return(_a0 storage.DataReference) *InputReader_GetInputPath_Call
func (*InputReader_GetInputPath_Call) Run ¶ added in v1.15.1
func (_c *InputReader_GetInputPath_Call) Run(run func()) *InputReader_GetInputPath_Call
func (*InputReader_GetInputPath_Call) RunAndReturn ¶ added in v1.15.1
func (_c *InputReader_GetInputPath_Call) RunAndReturn(run func() storage.DataReference) *InputReader_GetInputPath_Call
type InputReader_GetInputPrefixPath_Call ¶ added in v1.15.1
InputReader_GetInputPrefixPath_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetInputPrefixPath'
func (*InputReader_GetInputPrefixPath_Call) Return ¶ added in v1.15.1
func (_c *InputReader_GetInputPrefixPath_Call) Return(_a0 storage.DataReference) *InputReader_GetInputPrefixPath_Call
func (*InputReader_GetInputPrefixPath_Call) Run ¶ added in v1.15.1
func (_c *InputReader_GetInputPrefixPath_Call) Run(run func()) *InputReader_GetInputPrefixPath_Call
func (*InputReader_GetInputPrefixPath_Call) RunAndReturn ¶ added in v1.15.1
func (_c *InputReader_GetInputPrefixPath_Call) RunAndReturn(run func() storage.DataReference) *InputReader_GetInputPrefixPath_Call
type InputReader_Get_Call ¶ added in v1.15.1
InputReader_Get_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Get'
func (*InputReader_Get_Call) Return ¶ added in v1.15.1
func (_c *InputReader_Get_Call) Return(_a0 *core.LiteralMap, _a1 error) *InputReader_Get_Call
func (*InputReader_Get_Call) Run ¶ added in v1.15.1
func (_c *InputReader_Get_Call) Run(run func(ctx context.Context)) *InputReader_Get_Call
func (*InputReader_Get_Call) RunAndReturn ¶ added in v1.15.1
func (_c *InputReader_Get_Call) RunAndReturn(run func(context.Context) (*core.LiteralMap, error)) *InputReader_Get_Call
type OutputDataSandbox ¶
RawOutputPaths is an autogenerated mock type for the RawOutputPaths type
func (*OutputDataSandbox) GetRawOutputPrefix ¶
func (_m *OutputDataSandbox) GetRawOutputPrefix() storage.DataReference
GetRawOutputPrefix provides a mock function with given fields:
func (*OutputDataSandbox) OnGetOutputDataSandboxPath ¶
func (_m *OutputDataSandbox) OnGetOutputDataSandboxPath() *OutputDataSandbox_GetOutputDataSandboxPath
func (*OutputDataSandbox) OnGetOutputDataSandboxPathMatch ¶
func (_m *OutputDataSandbox) OnGetOutputDataSandboxPathMatch(matchers ...interface{}) *OutputDataSandbox_GetOutputDataSandboxPath
type OutputDataSandbox_GetOutputDataSandboxPath ¶
func (OutputDataSandbox_GetOutputDataSandboxPath) Return ¶
func (_m OutputDataSandbox_GetOutputDataSandboxPath) Return(_a0 storage.DataReference) *OutputDataSandbox_GetOutputDataSandboxPath
type OutputFilePaths ¶
OutputFilePaths is an autogenerated mock type for the OutputFilePaths type
func NewOutputFilePaths ¶ added in v1.15.1
func NewOutputFilePaths(t interface {
mock.TestingT
Cleanup(func())
}) *OutputFilePaths
NewOutputFilePaths creates a new instance of OutputFilePaths. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*OutputFilePaths) EXPECT ¶ added in v1.15.1
func (_m *OutputFilePaths) EXPECT() *OutputFilePaths_Expecter
func (*OutputFilePaths) GetCheckpointPrefix ¶
func (_m *OutputFilePaths) GetCheckpointPrefix() storage.DataReference
GetCheckpointPrefix provides a mock function with no fields
func (*OutputFilePaths) GetDeckPath ¶
func (_m *OutputFilePaths) GetDeckPath() storage.DataReference
GetDeckPath provides a mock function with no fields
func (*OutputFilePaths) GetErrorPath ¶
func (_m *OutputFilePaths) GetErrorPath() storage.DataReference
GetErrorPath provides a mock function with no fields
func (*OutputFilePaths) GetOutputPath ¶
func (_m *OutputFilePaths) GetOutputPath() storage.DataReference
GetOutputPath provides a mock function with no fields
func (*OutputFilePaths) GetOutputPrefixPath ¶
func (_m *OutputFilePaths) GetOutputPrefixPath() storage.DataReference
GetOutputPrefixPath provides a mock function with no fields
func (*OutputFilePaths) GetPreviousCheckpointsPrefix ¶
func (_m *OutputFilePaths) GetPreviousCheckpointsPrefix() storage.DataReference
GetPreviousCheckpointsPrefix provides a mock function with no fields
func (*OutputFilePaths) GetRawOutputPrefix ¶
func (_m *OutputFilePaths) GetRawOutputPrefix() storage.DataReference
GetRawOutputPrefix provides a mock function with no fields
type OutputFilePaths_Expecter ¶ added in v1.15.1
type OutputFilePaths_Expecter struct {
// contains filtered or unexported fields
}
func (*OutputFilePaths_Expecter) GetCheckpointPrefix ¶ added in v1.15.1
func (_e *OutputFilePaths_Expecter) GetCheckpointPrefix() *OutputFilePaths_GetCheckpointPrefix_Call
GetCheckpointPrefix is a helper method to define mock.On call
func (*OutputFilePaths_Expecter) GetDeckPath ¶ added in v1.15.1
func (_e *OutputFilePaths_Expecter) GetDeckPath() *OutputFilePaths_GetDeckPath_Call
GetDeckPath is a helper method to define mock.On call
func (*OutputFilePaths_Expecter) GetErrorPath ¶ added in v1.15.1
func (_e *OutputFilePaths_Expecter) GetErrorPath() *OutputFilePaths_GetErrorPath_Call
GetErrorPath is a helper method to define mock.On call
func (*OutputFilePaths_Expecter) GetOutputPath ¶ added in v1.15.1
func (_e *OutputFilePaths_Expecter) GetOutputPath() *OutputFilePaths_GetOutputPath_Call
GetOutputPath is a helper method to define mock.On call
func (*OutputFilePaths_Expecter) GetOutputPrefixPath ¶ added in v1.15.1
func (_e *OutputFilePaths_Expecter) GetOutputPrefixPath() *OutputFilePaths_GetOutputPrefixPath_Call
GetOutputPrefixPath is a helper method to define mock.On call
func (*OutputFilePaths_Expecter) GetPreviousCheckpointsPrefix ¶ added in v1.15.1
func (_e *OutputFilePaths_Expecter) GetPreviousCheckpointsPrefix() *OutputFilePaths_GetPreviousCheckpointsPrefix_Call
GetPreviousCheckpointsPrefix is a helper method to define mock.On call
func (*OutputFilePaths_Expecter) GetRawOutputPrefix ¶ added in v1.15.1
func (_e *OutputFilePaths_Expecter) GetRawOutputPrefix() *OutputFilePaths_GetRawOutputPrefix_Call
GetRawOutputPrefix is a helper method to define mock.On call
type OutputFilePaths_GetCheckpointPrefix_Call ¶ added in v1.15.1
OutputFilePaths_GetCheckpointPrefix_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetCheckpointPrefix'
func (*OutputFilePaths_GetCheckpointPrefix_Call) Return ¶ added in v1.15.1
func (_c *OutputFilePaths_GetCheckpointPrefix_Call) Return(_a0 storage.DataReference) *OutputFilePaths_GetCheckpointPrefix_Call
func (*OutputFilePaths_GetCheckpointPrefix_Call) Run ¶ added in v1.15.1
func (_c *OutputFilePaths_GetCheckpointPrefix_Call) Run(run func()) *OutputFilePaths_GetCheckpointPrefix_Call
func (*OutputFilePaths_GetCheckpointPrefix_Call) RunAndReturn ¶ added in v1.15.1
func (_c *OutputFilePaths_GetCheckpointPrefix_Call) RunAndReturn(run func() storage.DataReference) *OutputFilePaths_GetCheckpointPrefix_Call
type OutputFilePaths_GetDeckPath_Call ¶ added in v1.15.1
OutputFilePaths_GetDeckPath_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetDeckPath'
func (*OutputFilePaths_GetDeckPath_Call) Return ¶ added in v1.15.1
func (_c *OutputFilePaths_GetDeckPath_Call) Return(_a0 storage.DataReference) *OutputFilePaths_GetDeckPath_Call
func (*OutputFilePaths_GetDeckPath_Call) Run ¶ added in v1.15.1
func (_c *OutputFilePaths_GetDeckPath_Call) Run(run func()) *OutputFilePaths_GetDeckPath_Call
func (*OutputFilePaths_GetDeckPath_Call) RunAndReturn ¶ added in v1.15.1
func (_c *OutputFilePaths_GetDeckPath_Call) RunAndReturn(run func() storage.DataReference) *OutputFilePaths_GetDeckPath_Call
type OutputFilePaths_GetErrorPath_Call ¶ added in v1.15.1
OutputFilePaths_GetErrorPath_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetErrorPath'
func (*OutputFilePaths_GetErrorPath_Call) Return ¶ added in v1.15.1
func (_c *OutputFilePaths_GetErrorPath_Call) Return(_a0 storage.DataReference) *OutputFilePaths_GetErrorPath_Call
func (*OutputFilePaths_GetErrorPath_Call) Run ¶ added in v1.15.1
func (_c *OutputFilePaths_GetErrorPath_Call) Run(run func()) *OutputFilePaths_GetErrorPath_Call
func (*OutputFilePaths_GetErrorPath_Call) RunAndReturn ¶ added in v1.15.1
func (_c *OutputFilePaths_GetErrorPath_Call) RunAndReturn(run func() storage.DataReference) *OutputFilePaths_GetErrorPath_Call
type OutputFilePaths_GetOutputPath_Call ¶ added in v1.15.1
OutputFilePaths_GetOutputPath_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetOutputPath'
func (*OutputFilePaths_GetOutputPath_Call) Return ¶ added in v1.15.1
func (_c *OutputFilePaths_GetOutputPath_Call) Return(_a0 storage.DataReference) *OutputFilePaths_GetOutputPath_Call
func (*OutputFilePaths_GetOutputPath_Call) Run ¶ added in v1.15.1
func (_c *OutputFilePaths_GetOutputPath_Call) Run(run func()) *OutputFilePaths_GetOutputPath_Call
func (*OutputFilePaths_GetOutputPath_Call) RunAndReturn ¶ added in v1.15.1
func (_c *OutputFilePaths_GetOutputPath_Call) RunAndReturn(run func() storage.DataReference) *OutputFilePaths_GetOutputPath_Call
type OutputFilePaths_GetOutputPrefixPath_Call ¶ added in v1.15.1
OutputFilePaths_GetOutputPrefixPath_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetOutputPrefixPath'
func (*OutputFilePaths_GetOutputPrefixPath_Call) Return ¶ added in v1.15.1
func (_c *OutputFilePaths_GetOutputPrefixPath_Call) Return(_a0 storage.DataReference) *OutputFilePaths_GetOutputPrefixPath_Call
func (*OutputFilePaths_GetOutputPrefixPath_Call) Run ¶ added in v1.15.1
func (_c *OutputFilePaths_GetOutputPrefixPath_Call) Run(run func()) *OutputFilePaths_GetOutputPrefixPath_Call
func (*OutputFilePaths_GetOutputPrefixPath_Call) RunAndReturn ¶ added in v1.15.1
func (_c *OutputFilePaths_GetOutputPrefixPath_Call) RunAndReturn(run func() storage.DataReference) *OutputFilePaths_GetOutputPrefixPath_Call
type OutputFilePaths_GetPreviousCheckpointsPrefix_Call ¶ added in v1.15.1
OutputFilePaths_GetPreviousCheckpointsPrefix_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetPreviousCheckpointsPrefix'
func (*OutputFilePaths_GetPreviousCheckpointsPrefix_Call) Run ¶ added in v1.15.1
func (_c *OutputFilePaths_GetPreviousCheckpointsPrefix_Call) Run(run func()) *OutputFilePaths_GetPreviousCheckpointsPrefix_Call
func (*OutputFilePaths_GetPreviousCheckpointsPrefix_Call) RunAndReturn ¶ added in v1.15.1
func (_c *OutputFilePaths_GetPreviousCheckpointsPrefix_Call) RunAndReturn(run func() storage.DataReference) *OutputFilePaths_GetPreviousCheckpointsPrefix_Call
type OutputFilePaths_GetRawOutputPrefix_Call ¶ added in v1.15.1
OutputFilePaths_GetRawOutputPrefix_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetRawOutputPrefix'
func (*OutputFilePaths_GetRawOutputPrefix_Call) Return ¶ added in v1.15.1
func (_c *OutputFilePaths_GetRawOutputPrefix_Call) Return(_a0 storage.DataReference) *OutputFilePaths_GetRawOutputPrefix_Call
func (*OutputFilePaths_GetRawOutputPrefix_Call) Run ¶ added in v1.15.1
func (_c *OutputFilePaths_GetRawOutputPrefix_Call) Run(run func()) *OutputFilePaths_GetRawOutputPrefix_Call
func (*OutputFilePaths_GetRawOutputPrefix_Call) RunAndReturn ¶ added in v1.15.1
func (_c *OutputFilePaths_GetRawOutputPrefix_Call) RunAndReturn(run func() storage.DataReference) *OutputFilePaths_GetRawOutputPrefix_Call
type OutputReader ¶
OutputReader is an autogenerated mock type for the OutputReader type
func NewOutputReader ¶ added in v1.15.1
func NewOutputReader(t interface {
mock.TestingT
Cleanup(func())
}) *OutputReader
NewOutputReader creates a new instance of OutputReader. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*OutputReader) DeckExists ¶
func (_m *OutputReader) DeckExists(ctx context.Context) (bool, error)
DeckExists provides a mock function with given fields: ctx
func (*OutputReader) EXPECT ¶ added in v1.15.1
func (_m *OutputReader) EXPECT() *OutputReader_Expecter
func (*OutputReader) Exists ¶
func (_m *OutputReader) Exists(ctx context.Context) (bool, error)
Exists provides a mock function with given fields: ctx
func (*OutputReader) IsError ¶
func (_m *OutputReader) IsError(ctx context.Context) (bool, error)
IsError provides a mock function with given fields: ctx
func (*OutputReader) IsFile ¶
func (_m *OutputReader) IsFile(ctx context.Context) bool
IsFile provides a mock function with given fields: ctx
func (*OutputReader) Read ¶
func (_m *OutputReader) Read(ctx context.Context) (*core.LiteralMap, *io.ExecutionError, error)
Read provides a mock function with given fields: ctx
func (*OutputReader) ReadError ¶
func (_m *OutputReader) ReadError(ctx context.Context) (io.ExecutionError, error)
ReadError provides a mock function with given fields: ctx
type OutputReader_DeckExists_Call ¶ added in v1.15.1
OutputReader_DeckExists_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'DeckExists'
func (*OutputReader_DeckExists_Call) Return ¶ added in v1.15.1
func (_c *OutputReader_DeckExists_Call) Return(_a0 bool, _a1 error) *OutputReader_DeckExists_Call
func (*OutputReader_DeckExists_Call) Run ¶ added in v1.15.1
func (_c *OutputReader_DeckExists_Call) Run(run func(ctx context.Context)) *OutputReader_DeckExists_Call
func (*OutputReader_DeckExists_Call) RunAndReturn ¶ added in v1.15.1
func (_c *OutputReader_DeckExists_Call) RunAndReturn(run func(context.Context) (bool, error)) *OutputReader_DeckExists_Call
type OutputReader_Exists_Call ¶ added in v1.15.1
OutputReader_Exists_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Exists'
func (*OutputReader_Exists_Call) Return ¶ added in v1.15.1
func (_c *OutputReader_Exists_Call) Return(_a0 bool, _a1 error) *OutputReader_Exists_Call
func (*OutputReader_Exists_Call) Run ¶ added in v1.15.1
func (_c *OutputReader_Exists_Call) Run(run func(ctx context.Context)) *OutputReader_Exists_Call
func (*OutputReader_Exists_Call) RunAndReturn ¶ added in v1.15.1
func (_c *OutputReader_Exists_Call) RunAndReturn(run func(context.Context) (bool, error)) *OutputReader_Exists_Call
type OutputReader_Expecter ¶ added in v1.15.1
type OutputReader_Expecter struct {
// contains filtered or unexported fields
}
func (*OutputReader_Expecter) DeckExists ¶ added in v1.15.1
func (_e *OutputReader_Expecter) DeckExists(ctx interface{}) *OutputReader_DeckExists_Call
DeckExists is a helper method to define mock.On call
- ctx context.Context
func (*OutputReader_Expecter) Exists ¶ added in v1.15.1
func (_e *OutputReader_Expecter) Exists(ctx interface{}) *OutputReader_Exists_Call
Exists is a helper method to define mock.On call
- ctx context.Context
func (*OutputReader_Expecter) IsError ¶ added in v1.15.1
func (_e *OutputReader_Expecter) IsError(ctx interface{}) *OutputReader_IsError_Call
IsError is a helper method to define mock.On call
- ctx context.Context
func (*OutputReader_Expecter) IsFile ¶ added in v1.15.1
func (_e *OutputReader_Expecter) IsFile(ctx interface{}) *OutputReader_IsFile_Call
IsFile is a helper method to define mock.On call
- ctx context.Context
func (*OutputReader_Expecter) Read ¶ added in v1.15.1
func (_e *OutputReader_Expecter) Read(ctx interface{}) *OutputReader_Read_Call
Read is a helper method to define mock.On call
- ctx context.Context
func (*OutputReader_Expecter) ReadError ¶ added in v1.15.1
func (_e *OutputReader_Expecter) ReadError(ctx interface{}) *OutputReader_ReadError_Call
ReadError is a helper method to define mock.On call
- ctx context.Context
type OutputReader_IsError_Call ¶ added in v1.15.1
OutputReader_IsError_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'IsError'
func (*OutputReader_IsError_Call) Return ¶ added in v1.15.1
func (_c *OutputReader_IsError_Call) Return(_a0 bool, _a1 error) *OutputReader_IsError_Call
func (*OutputReader_IsError_Call) Run ¶ added in v1.15.1
func (_c *OutputReader_IsError_Call) Run(run func(ctx context.Context)) *OutputReader_IsError_Call
func (*OutputReader_IsError_Call) RunAndReturn ¶ added in v1.15.1
func (_c *OutputReader_IsError_Call) RunAndReturn(run func(context.Context) (bool, error)) *OutputReader_IsError_Call
type OutputReader_IsFile_Call ¶ added in v1.15.1
OutputReader_IsFile_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'IsFile'
func (*OutputReader_IsFile_Call) Return ¶ added in v1.15.1
func (_c *OutputReader_IsFile_Call) Return(_a0 bool) *OutputReader_IsFile_Call
func (*OutputReader_IsFile_Call) Run ¶ added in v1.15.1
func (_c *OutputReader_IsFile_Call) Run(run func(ctx context.Context)) *OutputReader_IsFile_Call
func (*OutputReader_IsFile_Call) RunAndReturn ¶ added in v1.15.1
func (_c *OutputReader_IsFile_Call) RunAndReturn(run func(context.Context) bool) *OutputReader_IsFile_Call
type OutputReader_ReadError_Call ¶ added in v1.15.1
OutputReader_ReadError_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'ReadError'
func (*OutputReader_ReadError_Call) Return ¶ added in v1.15.1
func (_c *OutputReader_ReadError_Call) Return(_a0 io.ExecutionError, _a1 error) *OutputReader_ReadError_Call
func (*OutputReader_ReadError_Call) Run ¶ added in v1.15.1
func (_c *OutputReader_ReadError_Call) Run(run func(ctx context.Context)) *OutputReader_ReadError_Call
func (*OutputReader_ReadError_Call) RunAndReturn ¶ added in v1.15.1
func (_c *OutputReader_ReadError_Call) RunAndReturn(run func(context.Context) (io.ExecutionError, error)) *OutputReader_ReadError_Call
type OutputReader_Read_Call ¶ added in v1.15.1
OutputReader_Read_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Read'
func (*OutputReader_Read_Call) Return ¶ added in v1.15.1
func (_c *OutputReader_Read_Call) Return(_a0 *core.LiteralMap, _a1 *io.ExecutionError, _a2 error) *OutputReader_Read_Call
func (*OutputReader_Read_Call) Run ¶ added in v1.15.1
func (_c *OutputReader_Read_Call) Run(run func(ctx context.Context)) *OutputReader_Read_Call
func (*OutputReader_Read_Call) RunAndReturn ¶ added in v1.15.1
func (_c *OutputReader_Read_Call) RunAndReturn(run func(context.Context) (*core.LiteralMap, *io.ExecutionError, error)) *OutputReader_Read_Call
type OutputWriter ¶
OutputWriter is an autogenerated mock type for the OutputWriter type
func NewOutputWriter ¶ added in v1.15.1
func NewOutputWriter(t interface {
mock.TestingT
Cleanup(func())
}) *OutputWriter
NewOutputWriter creates a new instance of OutputWriter. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*OutputWriter) EXPECT ¶ added in v1.15.1
func (_m *OutputWriter) EXPECT() *OutputWriter_Expecter
func (*OutputWriter) GetCheckpointPrefix ¶
func (_m *OutputWriter) GetCheckpointPrefix() storage.DataReference
GetCheckpointPrefix provides a mock function with no fields
func (*OutputWriter) GetDeckPath ¶
func (_m *OutputWriter) GetDeckPath() storage.DataReference
GetDeckPath provides a mock function with no fields
func (*OutputWriter) GetErrorPath ¶
func (_m *OutputWriter) GetErrorPath() storage.DataReference
GetErrorPath provides a mock function with no fields
func (*OutputWriter) GetOutputPath ¶
func (_m *OutputWriter) GetOutputPath() storage.DataReference
GetOutputPath provides a mock function with no fields
func (*OutputWriter) GetOutputPrefixPath ¶
func (_m *OutputWriter) GetOutputPrefixPath() storage.DataReference
GetOutputPrefixPath provides a mock function with no fields
func (*OutputWriter) GetPreviousCheckpointsPrefix ¶
func (_m *OutputWriter) GetPreviousCheckpointsPrefix() storage.DataReference
GetPreviousCheckpointsPrefix provides a mock function with no fields
func (*OutputWriter) GetRawOutputPrefix ¶
func (_m *OutputWriter) GetRawOutputPrefix() storage.DataReference
GetRawOutputPrefix provides a mock function with no fields
func (*OutputWriter) Put ¶
func (_m *OutputWriter) Put(ctx context.Context, reader io.OutputReader) error
Put provides a mock function with given fields: ctx, reader
type OutputWriter_Expecter ¶ added in v1.15.1
type OutputWriter_Expecter struct {
// contains filtered or unexported fields
}
func (*OutputWriter_Expecter) GetCheckpointPrefix ¶ added in v1.15.1
func (_e *OutputWriter_Expecter) GetCheckpointPrefix() *OutputWriter_GetCheckpointPrefix_Call
GetCheckpointPrefix is a helper method to define mock.On call
func (*OutputWriter_Expecter) GetDeckPath ¶ added in v1.15.1
func (_e *OutputWriter_Expecter) GetDeckPath() *OutputWriter_GetDeckPath_Call
GetDeckPath is a helper method to define mock.On call
func (*OutputWriter_Expecter) GetErrorPath ¶ added in v1.15.1
func (_e *OutputWriter_Expecter) GetErrorPath() *OutputWriter_GetErrorPath_Call
GetErrorPath is a helper method to define mock.On call
func (*OutputWriter_Expecter) GetOutputPath ¶ added in v1.15.1
func (_e *OutputWriter_Expecter) GetOutputPath() *OutputWriter_GetOutputPath_Call
GetOutputPath is a helper method to define mock.On call
func (*OutputWriter_Expecter) GetOutputPrefixPath ¶ added in v1.15.1
func (_e *OutputWriter_Expecter) GetOutputPrefixPath() *OutputWriter_GetOutputPrefixPath_Call
GetOutputPrefixPath is a helper method to define mock.On call
func (*OutputWriter_Expecter) GetPreviousCheckpointsPrefix ¶ added in v1.15.1
func (_e *OutputWriter_Expecter) GetPreviousCheckpointsPrefix() *OutputWriter_GetPreviousCheckpointsPrefix_Call
GetPreviousCheckpointsPrefix is a helper method to define mock.On call
func (*OutputWriter_Expecter) GetRawOutputPrefix ¶ added in v1.15.1
func (_e *OutputWriter_Expecter) GetRawOutputPrefix() *OutputWriter_GetRawOutputPrefix_Call
GetRawOutputPrefix is a helper method to define mock.On call
func (*OutputWriter_Expecter) Put ¶ added in v1.15.1
func (_e *OutputWriter_Expecter) Put(ctx interface{}, reader interface{}) *OutputWriter_Put_Call
Put is a helper method to define mock.On call
- ctx context.Context
- reader io.OutputReader
type OutputWriter_GetCheckpointPrefix_Call ¶ added in v1.15.1
OutputWriter_GetCheckpointPrefix_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetCheckpointPrefix'
func (*OutputWriter_GetCheckpointPrefix_Call) Return ¶ added in v1.15.1
func (_c *OutputWriter_GetCheckpointPrefix_Call) Return(_a0 storage.DataReference) *OutputWriter_GetCheckpointPrefix_Call
func (*OutputWriter_GetCheckpointPrefix_Call) Run ¶ added in v1.15.1
func (_c *OutputWriter_GetCheckpointPrefix_Call) Run(run func()) *OutputWriter_GetCheckpointPrefix_Call
func (*OutputWriter_GetCheckpointPrefix_Call) RunAndReturn ¶ added in v1.15.1
func (_c *OutputWriter_GetCheckpointPrefix_Call) RunAndReturn(run func() storage.DataReference) *OutputWriter_GetCheckpointPrefix_Call
type OutputWriter_GetDeckPath_Call ¶ added in v1.15.1
OutputWriter_GetDeckPath_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetDeckPath'
func (*OutputWriter_GetDeckPath_Call) Return ¶ added in v1.15.1
func (_c *OutputWriter_GetDeckPath_Call) Return(_a0 storage.DataReference) *OutputWriter_GetDeckPath_Call
func (*OutputWriter_GetDeckPath_Call) Run ¶ added in v1.15.1
func (_c *OutputWriter_GetDeckPath_Call) Run(run func()) *OutputWriter_GetDeckPath_Call
func (*OutputWriter_GetDeckPath_Call) RunAndReturn ¶ added in v1.15.1
func (_c *OutputWriter_GetDeckPath_Call) RunAndReturn(run func() storage.DataReference) *OutputWriter_GetDeckPath_Call
type OutputWriter_GetErrorPath_Call ¶ added in v1.15.1
OutputWriter_GetErrorPath_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetErrorPath'
func (*OutputWriter_GetErrorPath_Call) Return ¶ added in v1.15.1
func (_c *OutputWriter_GetErrorPath_Call) Return(_a0 storage.DataReference) *OutputWriter_GetErrorPath_Call
func (*OutputWriter_GetErrorPath_Call) Run ¶ added in v1.15.1
func (_c *OutputWriter_GetErrorPath_Call) Run(run func()) *OutputWriter_GetErrorPath_Call
func (*OutputWriter_GetErrorPath_Call) RunAndReturn ¶ added in v1.15.1
func (_c *OutputWriter_GetErrorPath_Call) RunAndReturn(run func() storage.DataReference) *OutputWriter_GetErrorPath_Call
type OutputWriter_GetOutputPath_Call ¶ added in v1.15.1
OutputWriter_GetOutputPath_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetOutputPath'
func (*OutputWriter_GetOutputPath_Call) Return ¶ added in v1.15.1
func (_c *OutputWriter_GetOutputPath_Call) Return(_a0 storage.DataReference) *OutputWriter_GetOutputPath_Call
func (*OutputWriter_GetOutputPath_Call) Run ¶ added in v1.15.1
func (_c *OutputWriter_GetOutputPath_Call) Run(run func()) *OutputWriter_GetOutputPath_Call
func (*OutputWriter_GetOutputPath_Call) RunAndReturn ¶ added in v1.15.1
func (_c *OutputWriter_GetOutputPath_Call) RunAndReturn(run func() storage.DataReference) *OutputWriter_GetOutputPath_Call
type OutputWriter_GetOutputPrefixPath_Call ¶ added in v1.15.1
OutputWriter_GetOutputPrefixPath_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetOutputPrefixPath'
func (*OutputWriter_GetOutputPrefixPath_Call) Return ¶ added in v1.15.1
func (_c *OutputWriter_GetOutputPrefixPath_Call) Return(_a0 storage.DataReference) *OutputWriter_GetOutputPrefixPath_Call
func (*OutputWriter_GetOutputPrefixPath_Call) Run ¶ added in v1.15.1
func (_c *OutputWriter_GetOutputPrefixPath_Call) Run(run func()) *OutputWriter_GetOutputPrefixPath_Call
func (*OutputWriter_GetOutputPrefixPath_Call) RunAndReturn ¶ added in v1.15.1
func (_c *OutputWriter_GetOutputPrefixPath_Call) RunAndReturn(run func() storage.DataReference) *OutputWriter_GetOutputPrefixPath_Call
type OutputWriter_GetPreviousCheckpointsPrefix_Call ¶ added in v1.15.1
OutputWriter_GetPreviousCheckpointsPrefix_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetPreviousCheckpointsPrefix'
func (*OutputWriter_GetPreviousCheckpointsPrefix_Call) Run ¶ added in v1.15.1
func (_c *OutputWriter_GetPreviousCheckpointsPrefix_Call) Run(run func()) *OutputWriter_GetPreviousCheckpointsPrefix_Call
func (*OutputWriter_GetPreviousCheckpointsPrefix_Call) RunAndReturn ¶ added in v1.15.1
func (_c *OutputWriter_GetPreviousCheckpointsPrefix_Call) RunAndReturn(run func() storage.DataReference) *OutputWriter_GetPreviousCheckpointsPrefix_Call
type OutputWriter_GetRawOutputPrefix_Call ¶ added in v1.15.1
OutputWriter_GetRawOutputPrefix_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetRawOutputPrefix'
func (*OutputWriter_GetRawOutputPrefix_Call) Return ¶ added in v1.15.1
func (_c *OutputWriter_GetRawOutputPrefix_Call) Return(_a0 storage.DataReference) *OutputWriter_GetRawOutputPrefix_Call
func (*OutputWriter_GetRawOutputPrefix_Call) Run ¶ added in v1.15.1
func (_c *OutputWriter_GetRawOutputPrefix_Call) Run(run func()) *OutputWriter_GetRawOutputPrefix_Call
func (*OutputWriter_GetRawOutputPrefix_Call) RunAndReturn ¶ added in v1.15.1
func (_c *OutputWriter_GetRawOutputPrefix_Call) RunAndReturn(run func() storage.DataReference) *OutputWriter_GetRawOutputPrefix_Call
type OutputWriter_Put_Call ¶ added in v1.15.1
OutputWriter_Put_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Put'
func (*OutputWriter_Put_Call) Return ¶ added in v1.15.1
func (_c *OutputWriter_Put_Call) Return(_a0 error) *OutputWriter_Put_Call
func (*OutputWriter_Put_Call) Run ¶ added in v1.15.1
func (_c *OutputWriter_Put_Call) Run(run func(ctx context.Context, reader io.OutputReader)) *OutputWriter_Put_Call
func (*OutputWriter_Put_Call) RunAndReturn ¶ added in v1.15.1
func (_c *OutputWriter_Put_Call) RunAndReturn(run func(context.Context, io.OutputReader) error) *OutputWriter_Put_Call
type RawOutputPaths ¶
RawOutputPaths is an autogenerated mock type for the RawOutputPaths type
func NewRawOutputPaths ¶ added in v1.15.1
func NewRawOutputPaths(t interface {
mock.TestingT
Cleanup(func())
}) *RawOutputPaths
NewRawOutputPaths creates a new instance of RawOutputPaths. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*RawOutputPaths) EXPECT ¶ added in v1.15.1
func (_m *RawOutputPaths) EXPECT() *RawOutputPaths_Expecter
func (*RawOutputPaths) GetRawOutputPrefix ¶
func (_m *RawOutputPaths) GetRawOutputPrefix() storage.DataReference
GetRawOutputPrefix provides a mock function with no fields
type RawOutputPaths_Expecter ¶ added in v1.15.1
type RawOutputPaths_Expecter struct {
// contains filtered or unexported fields
}
func (*RawOutputPaths_Expecter) GetRawOutputPrefix ¶ added in v1.15.1
func (_e *RawOutputPaths_Expecter) GetRawOutputPrefix() *RawOutputPaths_GetRawOutputPrefix_Call
GetRawOutputPrefix is a helper method to define mock.On call
type RawOutputPaths_GetRawOutputPrefix_Call ¶ added in v1.15.1
RawOutputPaths_GetRawOutputPrefix_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetRawOutputPrefix'
func (*RawOutputPaths_GetRawOutputPrefix_Call) Return ¶ added in v1.15.1
func (_c *RawOutputPaths_GetRawOutputPrefix_Call) Return(_a0 storage.DataReference) *RawOutputPaths_GetRawOutputPrefix_Call
func (*RawOutputPaths_GetRawOutputPrefix_Call) Run ¶ added in v1.15.1
func (_c *RawOutputPaths_GetRawOutputPrefix_Call) Run(run func()) *RawOutputPaths_GetRawOutputPrefix_Call
func (*RawOutputPaths_GetRawOutputPrefix_Call) RunAndReturn ¶ added in v1.15.1
func (_c *RawOutputPaths_GetRawOutputPrefix_Call) RunAndReturn(run func() storage.DataReference) *RawOutputPaths_GetRawOutputPrefix_Call